package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@$"`0`!```````````"``@````!`$`=D````#0``,(4$``0!0`T`"``
M"0`H`"(`(0````8````T`$``-`!``#0```$@```!(`````4````$`````P``
M`50`0`%4`$`!5`````T````-````!`````%P```````!A`!``80`0`&$````
M&````!@````$````!`````$``````$````!``````%NT``!;M`````4``0``
M`````0``8```06```$%@````720``&V0````!@`!```````"```!P`!``<``
M0`'````!0````4`````'````!`````0```%D`$`!9`!``60````@````(```
M``0````$````!````9P`0`&<`$`!G````"0````D````!`````0`````````
M````````````````````````````````!"]L:6(O;&0N<V\N,0`````````$
M````$`````%'3E4```````````(````&````&K(``?8`````````````````
M`````$(\X`````0````4`````T=.50`/4:9M]+Z%G->&=;UV)5`3V-:TTP``
M``$```!"`````0```C(````!```"/0````$```)'`````0```J@````!```#
MSP````$```/I````#`!`%H@````-`$!7D`````0`0`,`````!0!`#4P````&
M`$`&3`````H```5L````"P```!!P```6`$&[X````!4``````````P!!O/``
M```1`$`42````!(````X````$P````AP```!`````7````4````"<```!@!`
M``!P```*````"7```!$```!P<```$@```"%P```3````;0```!0````1````
M%P!`%(`````"```""'```#(`0;OD;____@!`$YAO____`````V____``0!*X
M````````````````````````````````````````````````````````````
M````````80```'````````````````````!A``````````````!5````````
M`#\```!D````*0`````````N````*````"P`````````'````$X````#````
M-@```!,````Q````/@```%H``````````````!L```!!````90``````````
M````:0```%,````]````60````````!'````9@```%P```!(`````````$H`
M````````4``````````W````:`````````!>````3P```!X````S````)@``
M````````````3````&X```!#````-```````````````10`````````Y````
M`````%\```!L``````````T```!G````8P```%T````U````8@``````````
M`````0```"$````[````"0```&`````P````20````````!K````6```````
M````````.@```$L`````````/````%0````X````:@```%8```!"````````
M````````````````````````````````````````````"```````````````
M"@``````````````#```````````````````````````````!P``````````
M``````````0````6````````````````````````````````````````````
M`````````````!T````?`````````````````````````!H`````````````
M``````!O````"P```!<````&`````````"L````B````$@```",`````````
M)0`````````0`````````"\```````````````````!M`````````"H````.
M````$0`````````%````)````$8`````````````````````````30``````
M```R````%``````````9``````````````!$````4@``````````````)P``
M`````````````@``````````````40````````````````````````!;````
M%0```"T```!7``````````````!```````````\````8````(```````````
M```````````````1`$!60`````@2```/```#"P``````````$@``````!",`
M0#MX````"!(```\```+=```````````2````````4@````$`````$P#_\0``
M`G@``````````!(```````2#`$%@(``````A```7```#Q0!!O3`````$$0``
M'```!$8``````````!(```````.^`$&].`````01```<```"\@``````````
M$@``````!#0`0$&@````.!(```\```"1```````````2```````#;0``````
M````$@```````]<`0;U`````!!$``!P```1/`$!4[````+02```/```")```
M````````$@```````&T`0!>@`````!((``````0%`$&])``````0`/_Q```#
M00``````````$@```````'T``````````!(```````",```````````2````
M````&P!`5Y``````$@``$0```X0``````````!(```````.5```````````2
M```````"&0!!O40````$$0``'````NL``````````!(```````"6````````
M```2```````"#`!!O4@````!$0``'````KH``````````!(```````,9````
M```````2```````!_@``````````$@``````!%L`0#V`````1!(```\```1H
M`$`]Q````7`2```/```$=`!`0S@```UX$@``#P```>P``````````!(`````
M``"D```````````2```````!W@``````````$@```````GT``````````!(`
M``````+6```````````2```````!RP``````````$@```````[8`````````
M`!(```````'7```````````2```````$@0!!8"``````$0``%P```;L`````
M`````!(```````,J```````````2```````#IP!`5]`````$$0``$@```_X`
M06`@`````!```!<```2.`$`ZN````,`2```/```!K`!!O4P````3$0``'```
M`Q(``````````!(```````"O```````````2```````#?0``````````$@``
M`````R\``````````!(```````!C`$&[X``````1```8```"<0``````````
M$@```````9\``````````!(````````!`$!62````+`2```/```!B@``````
M````$@```````7\``````````!(```````+D```````````2```````#1P``
M````````$@```````W0``````````!(```````"^`$`9H``````2"``````$
M'@!!S9``````$`#_\0```H4``````````!(```````--```````````2````
M````T0``````````$@```````R(``````````!(```````%S```````````2
M```````$I`!`/S0```'X$@``#P```-\``````````!(```````%B````````
M```2```````"SP``````````$@``````!`P`0;TD`````!``__$```2Q`$`Z
M$````$`2```/````+@!`&S````)4$@``#P``!+D`0CS@`````!,`__$```3"
M`$`=D``````2```/```$R@``````````$0``````!-D`0#N````"`!(```\`
M``-4```````````2```````$Y@!`0=@```%@$@``#P``!/@`0$$L````=!(`
M``\```%4```````````2````````Z@!`&E``````$@@`````!08`0%6@````
M4!(```\```/W`$`;,``````0```/```!0```````````(````````3$`````
M`````!(```````#[```````````2```````#90``````````$@```````UL`
M`````````!(```````$$`$&\\``````1`/_Q```$&`!!O20`````$`#_\0``
M`1H``````````!(```````+Z```````````2```````#QP!!O3`````$(0``
M'````S<``````````!(```````)=```````````2```````#G```````````
M$@``````!+,`0!:(`````!(```T```)7```````````2```````#`@``````
M````$@``````!2(`0%"P```$/!(```\```*R```````````2```````$U0!"
M/.``````$`#_\0```L$``````````!(````````A`$!7<``````2````````
M,P``````````(@```````I8`0%=@`````!(`````7U]L:6)C7V-S=5]I;FET
M`%]?;&EB8U]C<W5?9FEN:0!?7VQI8F-?<W1A<G1?;6%I;@!?7V=M;VY?<W1A
M<G1?7P!L:6)P97)L+G-O+C4N,30`7T193D%-24-?3$E.2TE.1P!?7U),1%]-
M05``8F]O=%]$>6YA3&]A9&5R`'!E<FQ?8V]N<W1R=6-T`'!E<FQ?9G)E90!P
M97)L7V1E<W1R=6-T`'!E<FQ?86QL;V,`4&5R;%]S>7-?:6YI=#,`4&5R;%]A
M=&9O<FM?=6YL;V-K`%!E<FQ?<WES7W1E<FT`<&5R;%]P87)S90!097)L7V%T
M9F]R:U]L;V-K`'!E<FQ?<G5N`%]'3$]"04Q?3T9&4T547U1!0DQ%7P!097)L
M7W-A=F5?9&5S=')U8W1O<E]X`%!E<FQ?<W9?<V5T<'9N`%]*=E]296=I<W1E
M<D-L87-S97,`4&5R;%]A=E]F971C:`!097)L7VYE=UA37V9L86=S`%!E<FQ?
M;6=?<V5T`%!E<FQ?;F5W6%,`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%]N
M97=35G!V`%!,7VUE;6]R>5]W<F%P`%!E<FQ?9W9?9F5T8VAP=@!097)L7W-A
M9F5S>7-M86QL;V,`4&5R;%]D;W5N=VEN9`!097)L7W-V7S)P=E]F;&%G<P!0
M97)L7W-V7W-E='!V`%!,7V1O7W5N9'5M<`!03%]T:')?:V5Y`%!E<FQ?879?
M<VAI9G0`;&EB9&PN<V\N,@!L:6)M+G-O+C8`;&EB<'1H<F5A9"YS;RXP`&-L
M;W-E`'!T:')E861?9V5T<W!E8VEF:6,`;W!E;C8T`')E860`;'-E96LV-`!?
M7V5R<FYO7VQO8V%T:6]N`%]?<F5G:7-T97)?871F;W)K`&QI8F,N<V\N-@!O
M<&5N9&ER`&5X96-V<`!?7V-T>7!E7V)?;&]C`&%C8V5S<P!G971P:60`<W1R
M8VUP`&UE;7-E=`!U;FQI;FL`;65M;6]V90!S=')N8VUP`&-L;W-E9&ER`'-T
M<G-T<@!S=')C:'(`<F5A9&QI;FL`<W1R;F-P>0!E>&ET`&9P<FEN=&8`7U]X
M<W1A=#8T`')M9&ER`&UK9&ER`&UE;6-H<@!S=')T;VL`<F5A9&1I<C8T`'-P
M<FEN=&8`;65M8W!Y`%]?<W1R9'5P`'-T<FQE;@!?7W-T86-K7V-H:U]F86EL
M`&=E='5I9`!?7VQX<W1A=#8T`%])3U]S=&1I;E]U<V5D`')E86QL;V,`<W1D
M97)R`%]?96YV:7)O;@!L9"YS;RXQ`%]?<W1A8VM?8VAK7V=U87)D`&QI8F-R
M>7!T+G-O+C$`7V9T97AT`%]F9&%T80!?961A=&$`7U]B<W-?<W1A<G0`7V9B
M<W,`7V5N9`!P87)?8W5R<F5N=%]E>&5C`&=E=%]U<V5R;F%M95]F<F]M7V=E
M='!W=6ED`'!A<E]C;&5A;G5P`'!A<E]B87-E;F%M90!P87)?9&ER;F%M90!P
M87)?;6MT;7!D:7(`7U]D871A7W-T87)T`'!A<E]C=7)R96YT7V5X96-?<')O
M8P!P87)?:6YI=%]E;G8`>'-?:6YI=`!?9W!?9&ES<`!?7W-T87)T`%]?9VYU
M7VQO8V%L7V=P`'!A<E]F:6YD<')O9P!P87)?<V5T=7!?;&EB<&%T:`!P87)?
M96YV7V-L96%N`%A37TEN=&5R;F%L<U]005)?0TQ%05)35$%#2P!84U]);G1E
M<FYA;'-?4$%27T)/3U0`1TQ)0D-?,BXT`$=,24)#7S(N,@!'3$E"0U\R+C``
M1TQ)0D-?,BXS`$=,24)#7S(N,RXR``````$``@`!``(``0`#``$``@`"``(`
M`@`!``(``@`$``$```````$``@```````0`%``(````"```````"``(````!
M``$``0`````````'``(````"``(``0````(``0`!``$````"`````@`"``$`
M!P````$```````(``@`"`````0`#``(````"`````0```````@`!``$``0``
M``$````!``(``0`!```````!``$``````````@`(``$``0````(``@`(``,`
M"``!``,``@`!``(``0`)``(````&``$``0```\\````0````(`UI:10````$
M```%.````````0`"```"1P```!`````P#6EI$@````<```5"````$`UI:1``
M```#```%3````````0`%```"J````!``````#6EI$P````D```56````$`UI
M:1(````(```%0@```!`):1ER````!@``!6`````0#6EI%`````4```4X````
M$`UI:1`````"```%3`````````````````!!O3````A^`$&].```"GX`0;U`
M```/?@!!O40``!I^`$&]2```'7X`0;U,```R?@!!N^P```)_`$&[\```!'\`
M0;OT```&?P!!N_@```E_`$&[_```"W\`0;P````-?P!!O`0```Y_`$&\"```
M$7\`0;P,```2?P!!O!```!1_`$&\%```%7\`0;P8```6?P!!O!P``!A_`$&\
M(```&7\`0;PD```;?P!!O"@``!Q_`$&\+```'G\`0;PP```??P!!O#0``"!_
M`$&\.```)'\`0;P\```E?P!!O$```"9_`$&\1```)W\`0;Q(```H?P!!O$P`
M`"E_`$&\4```*G\`0;Q4```K?P!!O%@``"U_`$&\7```+G\`0;Q@```S?P!!
MO&0``#1_`$&\:```-7\`0;QL```V?P!!O'```#A_`$&\=```.7\`0;QX```[
M?P!!O'P``#Q_`$&\@```/7\`0;R$```^?P!!O(@``#]_`$&\C```0'\`0;R0
M``!"?P!!O)0``$-_`$&\F```1'\`0;R<``!%?P!!O*```$9_`$&\I```2'\`
M0;RH``!)?P!!O*P``$I_`$&\L```4G\`0;RT``!5?P!!O+@``%9_`$&\O```
M6G\`0;S```!;?P!!O,0``%Q_`$&\R```77\`0;S,``!@?P!!O-```&%_`$&\
MU```8W\`0;S8``!D?P!!O-P``&5_`$&\X```9W\`0;SD``!H?P!!O.@``&I_
M`$&\[```;'\\'``")YPF6`.9X"$GO?_@K[\`'*^\`!"/@H`X`"`()1!```4`
M(`@ECYF`.``@""4#(/@)`"`()001``$`(`@E#!`'HP`@""4$$0`!`"`()0P0
M%<``(`@EC[\`'``@""4#X``()[T`(``````````````````````\'`!"CYF[
MY"><N^0#',`C`^!X(0`8P((#(/@))QC__CP/`$*-^;OL`R``""7XN^P\#P!"
MC?F[\`,@``@E^+OP/`\`0HWYN_0#(``()?B[]#P/`$*-^;OX`R``""7XN_@\
M#P!"C?F[_`,@``@E^+O\/`\`0HWYO``#(``()?B\`#P/`$*-^;P$`R``""7X
MO`0\#P!"C?F\"`,@``@E^+P(/`\`0HWYO`P#(``()?B\##P/`$*-^;P0`R``
M""7XO!`\#P!"C?F\%`,@``@E^+P4/`\`0HWYO!@#(``()?B\&#P/`$*-^;P<
M`R``""7XO!P\#P!"C?F\(`,@``@E^+P@/`\`0HWYO"0#(``()?B\)#P/`$*-
M^;PH`R``""7XO"@\#P!"C?F\+`,@``@E^+PL/`\`0HWYO#`#(``()?B\,#P/
M`$*-^;PT`R``""7XO#0\#P!"C?F\.`,@``@E^+PX/`\`0HWYO#P#(``()?B\
M/#P/`$*-^;Q``R``""7XO$`\#P!"C?F\1`,@``@E^+Q$/`\`0HWYO$@#(``(
M)?B\2#P/`$*-^;Q,`R``""7XO$P\#P!"C?F\4`,@``@E^+Q0/`\`0HWYO%0#
M(``()?B\5#P/`$*-^;Q8`R``""7XO%@\#P!"C?F\7`,@``@E^+Q</`\`0HWY
MO&`#(``()?B\8#P/`$*-^;QD`R``""7XO&0\#P!"C?F\:`,@``@E^+QH/`\`
M0HWYO&P#(``()?B\;#P/`$*-^;QP`R``""7XO'`\#P!"C?F\=`,@``@E^+QT
M/`\`0HWYO'@#(``()?B\>#P/`$*-^;Q\`R``""7XO'P\#P!"C?F\@`,@``@E
M^+R`/`\`0HWYO(0#(``()?B\A#P/`$*-^;R(`R``""7XO(@\#P!"C?F\C`,@
M``@E^+R,/`\`0HWYO)`#(``()?B\D#P/`$*-^;R4`R``""7XO)0\#P!"C?F\
MF`,@``@E^+R8/`\`0HWYO)P#(``()?B\G#P/`$*-^;R@`R``""7XO*`\#P!"
MC?F\I`,@``@E^+RD/`\`0HWYO*@#(``()?B\J#P/`$*-^;RL`R``""7XO*P\
M#P!"C?F\L`,@``@E^+RP/`\`0HWYO+0#(``()?B\M#P/`$*-^;RX`R``""7X
MO+@\#P!"C?F\O`,@``@E^+R\/`\`0HWYO,`#(``()?B\P#P/`$*-^;S$`R``
M""7XO,0\#P!"C?F\R`,@``@E^+S(/`\`0HWYO,P#(``()?B\S#P/`$*-^;S0
M`R``""7XO-`\#P!"C?F\U`,@``@E^+S4/`\`0HWYO-@#(``()?B\V#P/`$*-
M^;S<`R``""7XO-P\#P!"C?F\X`,@``@E^+S@/`\`0HWYO.0#(``()?B\Y#P/
M`$*-^;SH`R``""7XO.@\#P!"C?F\[`,@``@E^+SL)[W_T*^D`#"OI0`TKZ8`
M.">D`#`GI0`T)Z8`.*^_`"ROL@`HK[$`)`P0!D"OL``@/`4`0"2E&:`\!`!`
M)(0:4`P0%7X`H#`A/`(`0H!"O4@00`!7/!``0@P0!K2.!+U$D$,$'XX$O40T
M8P`"#!`&M*!#!!^/I``PD$,$'R2$``5$A!``-&,``:!#!!\$@`!?1H`0(42`
M$``\`@!`1(`8```@""5&(@``U$);J$8@$#P`(`@E10$`8SP%`$(,$`8H``0@
M@(^C`#2/I@`PC&0``#P'`$*L1```/`0`0"2$6V2L1``$/`0`022$8#2L1``(
M/`0`0"2$6VBLXLUTK$0`#"0'``0\!`!"*,4``A2@``FLA\UX`$`H(20$``&,
M9P`$)(0``:RG`!`D8P`$%(;_^R2E``0DQ@`#``88@#P0`$(`0Q@AC@3-@#P%
M`$"L8```)*4Z4`!`."$,$`:`KZ``$!!``!\`0(@A#!`&!(X$S8`\!`!`#!`,
MJ"2$6*000``</!(`0@P0!?2.!,V`#!`&=``@""6/OP`L`B`0(8^R`"B/L0`D
MC[``(`/@``@GO0`P#!`&&``@""4\`P!"$$``'ZQBS8``0"`A#!`%\#P0`$(,
M$`:TC@2]1`@0!N*@0`/<#!`&G(X$S8`($`<F`$"((8Y$S7P0@``)`"`()0P0
M%3L`(`@E"!`'+0`@""4\`@!`U$);H`@0!O%&(@``/`0`0`P0#*@DA%A``$`@
M(1!`_]6N0LU\"!`'2P`@""4,$`8X)`0``3P$`$`DA%HX#!`&5"2EO4P`````
M```````````#X``A!!$``0`@""4\'`!")YP\X```^"&/A(`8CZ4``">F``0D
M`?_X`Z'H)">]_^"/AX`<CXB`(``@""6OJ``0KZ(`%*^]`!B/F8`T`"`()0,@
M^`D`(`@E$`#__P`@""4GO?_0K[,`*#P3`$*28KU@K[\`+*^R`"2OL0`@%$``
M&*^P`!P\$@!!/!$`02928`@F,6`,/!``0@(RB"..`KUD`!&(@R8Q__\`41@K
M$&``"B1"``$``AB``D,8(8QY```#(/@)K@*]9(X"O60`41@K%&#_^"1"``$D
M`@`!HF*]8(^_`"R/LP`HC[(`)(^Q`""/L``<`^``"">]`#`\!`!!C()@$!!`
M``<`(`@E/!D``"<Y```3(``#`"`()0,@``@DA&`0`^``"``@""4`(`@E)[W]
M>*^Q`H2OL`*`)(,`.`.@$"$GIP"`C&8``(QE``2L1@`$K$```*Q```BL10`,
M)$(`$!1'__@D8P`()Z(`:">L`FB,2__8C$8``(Q*_]R,10`$C$G_J(Q(_ZR,
M0_^<C$?_F`%F,"8!12@F`28P)@$%*"8`92@F`.8P)@`%'\(`!C!``,,8)0`%
M*$``91@EK$``&*Q#`!PD0@`(%$S_Z8^G``2,A0`$C(P``(R(``R,BP`DC(T`
M"(R)`!2,B@`<``QQ0``%-L(\`UJ"-&-YF0%G."$!QC`E``AX)P`%<4``#6^`
M``@0@H^P``P`SC`E`>IX)`$H<"0!HA`E`.,X(0`(;X``36@E`.8X(0'N$"4`
M!7`G`.(X(0&E,"0!R7`D`5"`(0`,9X``!1""C[@`%`(#@"$`!W["`8(0)0#.
M,"4`!6>```=Q0`!,8"4"!C`A`>X0)0`'@"<`PC`A`3C`(0#L$"0"#8`DC[$`
M'`,#P"$"`H`E``9Y0``&%L(`!W""``<_@`''<"4`3Q`E`Q`X(0`&>"<`XA`A
M`B.((0#.."0!['@DC[@`)`(MB"$``H%``>=X)0`&:((``C["``8W@`&F:"4"
M+W@A`/`X)0`","<!YS@A`P/`(0!->"0`SC`DC[$`+`,,P"$`!X;"`,\P)0`"
M8((`!WE```(7@`&"8"4#!C`A`@\0)0`'@"<`PC`A`B.((0#L$"0"#8`DC[@`
M-`(NB"$"`H`E``9Y0``&%L(`!W""``<_@`''<"4`3Q`E`C`X(0`&>"<`XA`A
M`P/`(0#.."0!['@DC[$`/`,-P"$``H%``>=X)0`&:((``C["``8W@`&F:"4#
M#W@A`/`X)0`","<!YS@A`B.((0!->"0`SC`DC[@`1`(LB"$`!X;"`,\P)0`"
M8((`!WE```(7@`&"8"4")C`A`@\0)0`'@"<`PC`A`P/`(0#L$"0"#8`DC[$`
M3`,.P"$"`H`E``9Y0``&%L(`!W""``<_@`''<"4`3Q`E`Q`X(0`&>"<`XA`A
M`B.((0#.."0!['@DC[@`5`(MB"$``H%``>=X)0`&:((``C["``8W@`&F:"4"
M+W@A`/`X)0`","<!YS@A`P/`(0!->"0`SC`DC[$`7`,,P"$`!X;"`,\P)0`"
M8((`!WE```(7@`&"8"4#!C`A`@\0)0`'@"<`PC`A`B.((0#L$"0"#8`DC[@`
M9`(NB"$"`H`E``9Y0``&%L(`!W""``<_@`''<"4`3Q`E`C`X(0`&>"<`XA`A
M`P/`(0#.."0!['@DC[$`;`,-P"$``H%``>=X)0`&:((``C["``8W@`&F:"4#
M#W@A`/`X)0`","<!YS@A`B.((0!->"0`SC`DC[@`=`(LB"$`!X;"`,\P)0`"
M8((`!WE```(7@`&"8"4")C`A`@\0)0`'@"<`PC`A`P/`(0#L$"0"#8`DC[$`
M?`,.P"$"`H`E``9Y0``&%L(`!W""``<_@`''<"4`3Q`E`Q`X(0`&>"<`XA`A
M`B.((0#.."0!['@DC[@`A`(MB"$``H%``>=X)0`&:((``C["``8W@`&F:"4"
M+W@A`/`X)0`","<!YS@A`$V`)`,#P"$`SC`DCZ\`C`,,P"$`!X["`-`P)0`"
M8((`!X%```(7@`&"8"4#!C`A`C`0)0`'B"<`PC`A`>-X(0#L$"0"+8@DC[``
ME`(BB"4`!\""`>YP(0`&%L(`!GE```<_@`,'."4!T7`A`$\0)0`&B"<!PA`A
M`,=X)`(#@"$"+(@DCZX`G`(OB"4`!L""`@UH(0`">4```H;"``8W@`,&,"4"
M#W@E`;%H(0`"B"<!KV@A`<-P(0(GB"0`1A@DCZ\`I`(CB"4`#8;"`<Q@(0`"
MR((`#7%```+'@#P#;MDT8^NA`S@0)0(.<"4!D6`A`8Y@(0'C>"$`1H@FCZX`
MK`(MB"8`#(;"``W`@@'G."$`#6^```QY0`,-:"4"#W@E`/$X(0#O."$!PW`A
M`:*()H^O`+0"+(@F``>&P@`,P((!QC`A``QG@``'<4`##&`E`@YP)0#1,"$`
MSC`A`>-X(0&-P":/K@"\`P?`)@`&CL(`!H%``>(0(0`'>((`!S^``>=X)0!8
M$"$",#@E`$<0(0'#<"$![#@FC[@`Q`'-:"$``H["``*!0`#F."8`!G""``8W
M@`'&<"4!IS@A`C`P)0#F."$#`\`A`<\P)H^M`,P##,`A``>.P@`'@4``PC`F
M``)@@@`"%X`!@F`E`P8P(0(P$"4`PC`A`8Z()@&C$"&/N`#4`B>()@`&@4``
M3W@A``=H@@`&%L(`!S^``:=H)0'Q>"$`4!`E`>(0(0&L."8#`\`AC[$`W`,.
MP"$``H;"``)Y0`#F."8`!G""``8W@`'&<"4#!S@A`@\P)0#F."$"(X@A`<TP
M)H^X`.0"+(@A``>&P@`'>4``PC`F``)@@@`"%X`!@F`E`B8P(0(/$"4`PC`A
M`8Z`)@,#P"&/L0#L`PW`(0('@"8`!GE```86P@`':((`!S^``:=H)0!/$"4#
M$#@A`.(0(0(CB"$!K#@FC[@`]`(NB"$``H;"``)Y0`#F."8`!G""``8W@`'&
M<"4")S@A`@\P)0#F."$#`\`A`<TP)H^Q`/P##,`A``>&P@`'>4``PC`F``)@
M@@`"%X`!@F`E`P8P(0(/$"4`PC`A`8Z`)@(CB"&/N`$$`BV((0('@"8`!GE`
M``86P@`':((`!S^``:=H)0!/$"4",#@A`.(0(0,#P"$!K#@FC[$!#`,.P"$`
M`H;"``)Y0`#F."8`!G""``8W@`'&<"4#!S@A`@\P)0#F."$"(X@A`<TP)H^X
M`10"+(@A``>&P@`'>4``PC`F``)@@@`"%X`!@F`E`B8P(0(/$"4`PC`A`8Z`
M)@,#P"&/L0$<`PW`(0('@"8`!GE```86P@`':((`!S^``:=H)0!/$"4#$#@A
M`.(0(0(CB"$!K#@FC[@!)`(NB"$``H;"``)Y0`#F."8`!G""``8W@`'&<"4"
M)S@A`@\P)0#F."$#`\`A`<TP)H^Q`2P##,`A``>&P@`'>4``PC`F``)@@@`"
M%X`!@F`E`P8P(0(/$"4`PC`A`8Z`)@(CB"&/N`$T`BV((0('@"8`!GE```86
MP@`':((`!S^``:=H)0!/$"4",#@A`.(0(0,#P"$!K#@FCZ\!/`,.P"$``H["
M``*!0`#F."8`!G""``8W@`'&<"4#!S@A`C`P)0#F."$!XQ@A`<W`)@`">((`
M`C>``>8P)8^Q`40#`L`F``>&P@!L8"$`!WE`/`./&S1CO-P"#W@E`9A@(0#.
M@"4!CV`A`B.((0#.>"0`\(`D``<0@@`'/X``1Q`EC[@!3`(/@"4"+6@A``Q^
MP@`,.4`!YS@E`;!H(0!&@"4!IV@A`$9X)`,#P"$!D(`D``PX@@`,9X``[#@E
MC[$!5`(/@"4##G`A``U^P@`-84`![&`E`=!P(0#B@"4!S'`A`.)X)`(CB"$!
ML(`D``U@@@`-;X`!C6`EC[@!7`(/@"4")C`A``YY0``.;L(`T#`A`:]H)0&'
M@"4`S6@A`8=X)`,#P"$!T(`D``XP@@`.=X``SC`EC[$!9`(/@"4#`A`A``UY
M0``-=L(`4!`A`<]P)0#,@"4`3G`A`,QX)`(CB"$!L(`D``T0@@`-;X``31`E
MC[@!;`(/@"4")S@A``YY0``.;L(`\#@A`:]H)0!&@"4`[6@A`$9X)`,#P"$!
MT(`D``XX@@`.=X``[C@EC[$!=`(/@"4##&`A``UY0``-=L(!D&`A`<]P)0#B
M@"4!CG`A`.)X)`(CB"$!L(`D``U@@@`-;X`!C6`EC[@!?`(/@"4")C`A``YY
M0``.;L(`T#`A`:]H)0&'@"4`S6@A`8=X)`,#P"$!T(`D``XP@@`.=X``SC`E
MC[$!A`(/@"4#`A`A``UY0``-=L(`4!`A`<]P)0#,@"4`3G`A`,QX)`(CB"$!
ML(`D``T0@@`-;X``31`EC[@!C`(/@"4")S@A``YY0``.;L(`\#@A`:]H)0!&
M@"4`[6@A`$9X)`,#P"$!T(`D``XX@@`.=X``[C@EC[$!E`(/@"4##&`A``UY
M0``-=L(!D&`A`<]P)0#B@"4!CG`A`.)X)`(CB"$!L(`D``U@@@`-;X`!C6`E
MC[@!G`(/@"4")C`A``YY0``.;L(`T#`A`:]H)0&'@"4`S6@A`8=X)`,#P"$!
MT(`D``XP@@`.=X``SC`EC[$!I`(/@"4#`A`A``UY0``-=L(`4!`A`<]P)0#,
M@"4`3G`A`,QX)`(CB"$!L(`D``T0@@`-;X``31`EC[@!K`(/@"4")S@A``YY
M0``.;L(`\#@A`:]H)0!&@"4`[6@A`$9X)`,#P"$!T(`D``XX@@`.=X``[C@E
MC[$!M`(/@"4##&`A``UY0``-=L(!D&`A`<]P)0#B@"4!CG`A`.)X)`(CB"$!
ML(`D``U@@@`-;X`!C6`EC[@!O`(/@"4")C`A``YY0``.;L(`T#`A`:]H)0&'
M@"4`S6@A`8=X)`,#P"$!T(`D``XP@@`.=X``SC`EC[$!Q`(/@"4#`A`A``UY
M0``-=L(`4!`A`<]P)0#,@"4`3G`A`,QX)`(CB"$!L(`D``T0@@`-;X``31`E
MC[@!S`(/@"4")S@A``YY0``.;L(`\#@A`$:()0&O:"4`[6@A`$:`)`,#P"$!
MT8@D``XX@@`.=X``[C@ECZ\!U`(PB"4##&`A``V&P@`-<4`"#G`E`9%@(0#B
M@"4!CF`A`>-X(0#B<"0`#8B"`;"`)``-;X`"+6@EC[D!W`(.@"4!YC`A``QQ
M0``,?L(![G`E`:?`)0#0,"$`SC`A`R/((0&8P"0!IQ@DCZX!Y`,#P"4`!H;"
M``R(@@,BR"$`!GE```QG@#P#RF(T8\'6`BQ@)0,X$"$"#W@E`$\0(0'#<"$!
MC<@FCZ\![`,FR"8``H;"`<<X(0`&P((``G%```8W@`,&P"4`^3@A`@XP)0#F
M."$!XW@A`PPP)H^N`?0![6@A``?.P@`'@4``PC`F``)X@@`"%X`!XG@E`:8P
M(0,P$"4`PC`A`?C()@'#$"&/K0'\`R?()@`&@4``3&`A``=P@@`&%L(`!S^`
M`<=P)0&98"$`4!`E`8(0(0'/."8!HV`A`9C`(8^M`@0``L["``*!0`#F."8`
M!F""``8W@`&&8"4#!S@A`S`P)0#F."$!HV@A`8XP)H^X`@P!KW@A``?.P@`'
M@4``PC`F``)H@@`"%X`!HF@E`>8P(0,P$"4`PC`A`:R`)@,#P"&/N0(4`P[`
M(0('@"8`!GE```86P@`'<((`!S^``<=P)0!/$"4#$#@A`.(0(0,CR"$!S3@F
MC[@"'`,LR"$``H;"``)Y0`#F."8`!F""``8W@`&&8"4#)S@A`@\P)0#F."$#
M`\`A`8XP)H^Y`B0##<`A``>&P@`'>4``PC`F``)H@@`"%X`!HF@E`P8P(0(/
M$"4`PC`A`:R`)@,CR"&/N`(L`R[((0('@"8`!GE```86P@`'<((`!S^``<=P
M)0!/$"4#,#@A`.(0(0,#P"$!S3@FC[D"-`,,P"$``H;"``)Y0`#F."8`!F""
M``8W@`&&8"4#!S@A`@\P)0#F."$#(\@A`8XP)H^X`CP#+<@A``>&P@`'>4``
MPC`F``)H@@`"%X`!HF@E`R8P(0(/$"4`PC`A`:R`)@,#P"&/N0)$`P[`(0('
M@"8`!GE```86P@`'<((`!S^``<=P)0!/$"4#$#@A`.(0(0,CR"$!S3@FC[@"
M3`,LR"$``H;"``)Y0`#F."8`!F""``8W@`&&8"4#)S@A`@\P)0#F."$#`\`A
M`8XP)H^Y`E0##<`A``>&P@`'>4``PC`F``)H@@`"%X`!HF@E`P8P(0(/$"4`
MPC`A`:R`)@,CR"&/N`)<`R[((0('@"8`!GE```86P@`'<((`!S^``<=P)0!/
M$"4#,#@A`.(0(0,#P"$!S3@FC[D"9`,,P"$``H;"``)Y0`#F."8`!F""``8W
M@`&&8"4#!S@A`@\P)0#F."$#(\@A`8XP)H^O`FP#+<@A``?&P@`'@4``PC`F
M``)H@@`"%X`!HF@E`R8P(0,0$"4`PC`A`:S`)@'C$"$#!\`FCZ\"=``&@4``
M!\B"`$YP(0`'/X``!A;"`R<X)0'8<"$`4!`E`<(0(0'C>"$`[<@FCZX"?`,F
MR"8``L;"``:`@@'L8"$`!C>```)Y0`(&,"4##W@E`9E@(0&/8"$!PQ@A`,?`
M)@,"P"8`;6@A``QY0``,'L(``G""`;AH(0!O&"4``A>``<(0)0&C&"$`92@A
M`8A`(0!)2"$`RC`A`.LX(:R```"/L0*$C[`"@*R%``2L@``(K(@`#*R``!"L
MB0`4K(``&*R&`!RL@``@K(<`)`/@``@GO0*()[W_R*^V`#"OLP`DK[\`-*^U
M`"ROM``HK[(`(*^Q`!ROL``8`("8(1"``"0`H+`A/`(`0HQ5O3`2H``@`"`(
M)8""```00``,``"0(20#`#T00P`)`"`()0"`D"$F4@`!@D(``!!```,`(`@E
M%$/_^P`@""4"4Y`CCK```!(```\"H(@A)!0`/0(`("$"8"@A#!`&K`)`,"$4
M0``$`A(8(8!B```05``0)D(``28Q``2.,```%@#_]0(`("&/OP`T```0(8^V
M`#"/M0`LC[0`*(^S`"2/L@`@C[$`'(^P`!@#X``()[T`.`(UB",`$8B#KM$`
M`(^_`#0"`A`AC[8`,(^U`"R/M``HC[,`)(^R`""/L0`<C[``&`/@``@GO0`X
M)[W_V*^_`"0,$`Q@)Z4`'(^_`"0#X``()[T`*">]_]"OL0`HK[``)*^_`"P`
M@(`A/!$`0@(`("$,$`Q@)Z4`'!!``!./OP`LCZ(`'(XCO3```A"``&(0(8Q#
M``008/_UK$,``"1"``B,0P``K$/__!1@__TD0@`$`@`@(0P0#&`GI0`<%$#_
M\8^B`!R/OP`LC[$`*(^P`"0#X``()[T`,">]_]BOL``8/!``0HX$O42OOP`D
MK[(`(`P0!K2OL0`<C$(!](X$O40,$`:TC%$`!(X$O40,$`:TD%(#U(Q"``0R
M4@!_E$(`$#!"_X`"0I`EIC(``@P0!K2.!+U$C$(!](X$O40,$`:TC%$`!#P%
M`$`DI5M@```P(0P0!E``0"`AC@2]1`P0!K2N(@`<C$(!](X$O40,$`:TC%$`
M!(Q"!-2.!+U$#!`&M*XB`"",0@'TC@2]1`P0!K2,40`$C$('!!!```4``!`A
M#!`&M(X$O42,0@<$C$(`<(X$O40,$`:TKB(`)(Q"`?2.!+U$C$(`!`P0!K2L
M0``HC$(!](X$O42,0@`$#!`&M*Q``!B,0@'TC@2]1`P0!K2,4``$C$(!_*X"
M`"R/OP`DC[(`((^Q`!R/L``8`^``"">]`"@GO?\HK[``N*^_`-2OM@#0K[4`
MS*^T`,BOLP#$K[(`P*^Q`+P0@``$`("`(8""```40``+`"`()8^_`-2/M@#0
MC[4`S(^T`,B/LP#$C[(`P(^Q`+R/L`"X`^``"">]`-@,$`;$`"`()1!`__,`
M0(@A/!4`0"02`"XFM5?4)!3__PP0!J0"("`A)%8`$Q!``"8"`"`AD$,`$Q!R
M`#$`(`@E#!`&1``@""4"P"`A#!`&1`!`F"$"8A`A#!`&,"1$``(`0)@A`L`X
M(0!`("$"H"@A#!`&H`(`,"$D!``#`F`H(0P0!K`GI@`8$%0`!@)@("&/HP`P
M)`)``#!C\``08@`B`"`()0P0!@``(`@E#!`%W`)@("$,$`:D`B`@(216`!,4
M0/_<`@`@(0P0!L`"("`A#!`%[`(`("&/OP#4C[8`T(^U`,R/M`#(C[,`Q(^R
M`,"/L0"\C[``N`/@``@GO0#8D$,`%!!@_\8`(`@E%'+_S``@""600@`5$$#_
MP0`@""4($`U'`"`()0P0#1\`(`@E"!`-8@`@""4GO?_8K[``'#P0`$*OL0`@
M`("((8X$O42OOP`D#!`&M``@""4D1@!@)`0``PP0!K@"("@A$$``!H^_`"0`
M`!`AC[$`((^P`!P#X``()[T`*`P0!K2.!+U$C$,`>"0"0``P8_``$&(`"0(@
M("$,$`:TC@2]1(Q#`'@T`J``,&/P`!1B_^Z/OP`D`B`@(0P0!H@D!0`"C[\`
M)"Q"``&/L0`@C[``'`/@``@GO0`H)[W_N*^Q`"BOL``DK[\`1*^W`$"OM@`\
MK[4`.*^T`#2OLP`PK[(`+("B```D`P`]`*"`(1!#`%D`@(@A#!`&1`(`("$"
M("`A)Z4`'`P0#&``0)@A$$``4P!`D"$,$`9$`$`@(0!3$"L00`!`C[4`'#P4
M`$(`%:B`@B(``!!``'$D`P`]$$,`;P(@$"$($`W7)`0`/1!D``4`(`@E)$(`
M`8!#```48/_[`"`()0!1("..@KTP)G,``@)D("$,$`8P`%6H(1!``&2NH@``
M/`(`0HQ#O3"/H@`<``(0@`!B$"&,0P``@B(``!!```V@8@``)`0`/1!$``LD
M`@`]"!`-\R8Q``$01``')`(`/8(B```D8P`!H&(``!1`__HF,0`!)`(`/:!B
M```D8P`!@@(``"80``&@8@``%$#__"1C``&/OP!$C[<`0(^V`#R/M0`XC[0`
M-(^S`#"/L@`LC[$`*(^P`"0#X``()[T`2(("```F$``!HD(``!!`__$F4@`!
M@@(``"80``&B0@``%$#_]R92``$($`X!C[\`1`@0#;\DL``!/!0`0HZ7O3".
MX@``$$``)B;B``0``)`A)$(`!(Q#__P48/_])E(``29%``(`!2B`/`(`0HQ#
MO7`08``-)`,``0P0!BP"X"`A`$"P(1!``!FN@KTP`!*H@"9"``$``A"``L*P
M(:[````($`W.K[(`'`"@("$,$`8PK$.]<!!```T`0+`A`!*H@`!`("$"X"@A
M#!`%V`*@,"$($`XOKI:],`@0#=P``"`A)`4`"`@0#B4``)`A"!`.`"0"__\G
MO>_(K[`0)#P0`$*OLA`LC@*]0`"`D"$\!`!`K[,0,"2$5]P`H)@A)`8/_R>E
M`!ROOQ`TK[$0**^B$!P,$`8,`"`()1A``!\GI!`@)%'__P"1&"&`8^_\$&``
M&">D`!P`0(@A)`4`+PP0!G`"(#`A$$``%#P"`$(,$`:TC$2]1`!`("$"0"@A
M)Z8`'`P0!I@"(#@ACZ,0'(X"O4`48@`2C[\0-(^S$#"/LA`LC[$0*(^P$"0#
MX``()[T0.!8@_^D`(`@E/`(`0@P0!K2,1+U$`$`@(0)`*"$,$`80`F`P(0@0
M#FT`(`@E#!`%^``@""4\`@!"C$2]1">]_^"OOP`<#!`&M``@""4\!0!`/`8`
M0#P'`$"/OP`<`$`@(22E5^PDQA>@).=8"`@0!E@GO0`@)[W_V*^P`"`\$`!"
MC@2]1*^_`"0,$`:T`"`()0P0#H0`0"`A#!`&M(X$O40\`P!`)&-;8#P%`$`\
M!@!``$`@(22E6!0DQE"P`&`X(:^C`!`,$`:$KZ``%(^_`"2/L``@`^``"">]
M`"@GO=_(K[`@*#P0`$*.`KU`K[\@-*^R(#"OL2`LKZ(@)`P0!B0`(`@E/`4`
M0#P'`$`GI``<)*58+`!`,"$,$`:@).=8.`1``!HGI``<)Z40(`P0!@PD!A``
M!$``%0!`D"$,$`8P)$0``1!```<`0(@A`D`P(0!`("$GI1`@#!`%X`(RD"&B
M0```CZ0@)(X#O4`4@P`)`B`0(8^_(#2/LB`PC[$@+(^P("@#X``()[T@.`@0
M#M```(@A#!`%^``@""4($`ZN`"`()2>][ZBOOA!0/!X`0J^R$#B/PKU``("0
M(3P$`$`DA%A`K[\05*^Q$#2OL!`PK[<03`"@@"&OMA!(K[401*^T$$"OLQ`\
MKZ(0+`P0#*@`(`@E`D`@(20%`"\,$`8\`$"((1!``!4"0"`A/`0`0"2$6$P,
M$`VP`D`H(8^D$"R/P[U`%(,`70)`$"&/OQ!4C[X04(^W$$R/MA!(C[401(^T
M$$"/LQ`\C[(0.(^Q$#2/L!`P`^``"">]$%@,$`9$/!0`0`(`("$FA5A<#!`&
MC`!`J"$00/_E`$`P(3P7`$`\%@!`)!``+R;W6&`FUEAH/!,`0H#"```40``"
M/`(`0"1&6#P2(``&`,`H(0(@("$,$`7,KZ8`)!!``":/I@`D`,`@(0P0!D2O
MI@`DCZ8`)`#"&"&`9/__%)``!@`@""6@8/__)&/__X!D__\0D/_\)$+__R1"
M``$`51`A*$(0`!!`_\("X"@A`L`X(2>D`"P,$`:@K[(`$`P0!K2.9+U$)$8`
M8"0$``,,$`:P)Z4`+!1```D``"`A#!`&M(YDO42,0P!X-`*``#!C\``08@`(
M)Z0`+```("$,$`:,)H587!1`_\P`0#`A"!`.^SP$`$`,$`:()`4``11`__8\
M!`!`)(183`P0#;`GI0`L#!`&9">D`"P($`[^`$"0(0P0!?@`(`@E@(4``!"@
M``TD@P`!`(`0(20&`"\0I@`'`"`()21C``&`9?__%*#_^P`@""4#X``(`"`(
M)0@0#V<`8!`A`^``"`"`$"$GO?_8K[$`(*^_`"2OL``<$(``(`"`B"&`@@``
M$$``'0`@""4,$`9$`"`()21&__\")C`A`B80*Q!``"HD`@`O@,,``!1B`!X`
M(`@E"!`/B20#`"^`P@``%$,`&0`@""4DQO__%-'_^P`@""6`PP``)`(`+Q!B
M`#4\!`!`C[\`)(^Q`""/L``<)(18:`@0!F0GO0`H#!`&,"0$``(00``#/`,`
M0)1C6#RD0P``C[\`)(^Q`""/L``<`^``"">]`"@($`^F)`,`+X#"```00P`%
M`"`()23&__\")A`K%$#_^@`@""40T?_A)`,`+R3&__\")A`K$$``!``@""6`
MP@``$$/_^@`@""4`T3`C),(``BQ"$`$00``+/!``0B8$O70"("@A#!`&>"3&
M``&/OP`D)@*]=(^Q`""/L``<`^``"">]`"@($`^<```0(0P0!C`D!``"$$#_
M^P!`&"$\`@!`E$18/`!@$"$($`^<I&0``">]_ZBOL`!`/!``0HX"O4`\`P!`
M)&-;<*^B`#ROOP!4K[0`4*^S`$ROL@!(K[$`1">B`!@D9``@C&@``(QG``2,
M9@`(C&4`#"1C`!"L2```K$<`!*Q&``BL10`,%&3_]B1"`!"48P``/`0`0*1#
M```,$`RO)(18;#P$`$`,$`RO)(18>#P$`$`,$`RO)(18@#P$`$`DA%B,#!`,
MKSP1`$`,$`RO)B18E#P$`$`DA%BD/!,`0`P0#*\\$@!`)F180`P0#*\\%`!`
M#!`,KR9$6+`,$`RO)H18O#P$`$`,$`RO)(18R#P$`$`,$`RO)(183#P$`$`,
M$`RO)(18U#P$`$`,$`RO)(18X#P$`$`,$`RH)(18[!!```,`0"@A#!`-L":$
M6+P\!`!`#!`,J"2$60`00``%`"`()3P$`$`DA%D4#!`-L`!`*"$\!`!`#!`,
MJ"2$62`00``3/`0`0"9D6$`,$`VP`$`H(3P%`$`F)%B4#!`-L"2E65"/HP`\
MC@*]0!1B`!N/OP!4C[0`4(^S`$R/L@!(C[$`1(^P`$`#X``()[T`6`P0#*@D
MA%DP$$``!29$6+`,$`VP`$`H(0@0$"@\!0!`/`4`0">D`"DDI5E$#!`&K"0&
M``H40/_C)D18L`P0#;`GI0`S"!`0*#P%`$`,$`7X`"`()2>]_^"OL``8/!``
M08X"8#`D`___$$,`!:^_`!R/OP`<C[``&`/@``@GO0`@/`0`0`P0#*@DA%BP
M$$``"P`@""6`0@``$$``"``@""4X0@`P``(0*ZX"8#"/OP`<C[``&`/@``@G
MO0`@```0(0@0$&&N`F`P)[W_X*^_`!P,$`7\`"`()0P0!=0`0"`A$$``!0`@
M""6,0@``C[\`'`/@``@GO0`@"!`0<0``$"$\`@!`)[W_H"1"662OH@`H/`(`
M0"1"66ROH@`L/`(`0"1"672OH@`P/`(`0"1"67ROL0!$KZ(`-#P1`$`\`@!`
MK[4`5*^T`%`F,5E4)$)9D#P5`$`\%`!`K[,`3*^R`$BOOP!<K[8`6*^P`$``
M@)@AK[$`)*^B`#BOH``\)[(`*":U6&`($!"A)I187`P0!<@`(`@E$$``'@`@
M""4F4@`$CE'__!(@`!&/OP!<#!`,J`(@("$`0(`A`F`H(1!```0`0"`A@$(`
M`!1`__``(`@E`B`@(0)@*"$,$`VP)E(`!(Y1__P6(/_QC[\`7(^V`%B/M0!4
MC[0`4(^S`$R/L@!(C[$`1(^P`$`#X``()[T`8`P0!D0"8"`A`@`@(0P0!D0`
M0+`A`L(0(0P0!C`D1``"`$"P(0!`("$"H"@A`F`P(0*`."$,$`:@K[``$`(@
M("$,$`VP`L`H(0@0$)XF4@`$)[V`$*^R?]`\$@!"K[9_X*^U?]ROM'_8K[-_
MU*^_?^ROOG_HK[=_Y*^Q?\ROL'_(CD*]0">]_I@T`X$L`'T8(:QB```\`@!`
M)$)9K*^B`%`\`@!`)$)8/*^B`%0\`@!`)$)9&*^B`#P\`@!`)$)9M*^B`$`\
M`@!`)$)81*^B`$0\`@!`)$)9O*^B`$@\%`!`/!8`0#P3`$`\`@!`)$)9P";6
M610F<UF<`("H(2:$6$"OH`!8K[8`.*^@`$ROLP!<KZ(`8`P0#*BOH`!D$$``
M!``@""6`0P``%&`!#@!`("$,$!!H`"`()1!``1$`0(`A@A$``!(@`!(T!8$P
M#!`&R``@""4"`!@A)`4`7XQ$````$8A``)&((98D```PA`@`%(```@`@""6@
M90``)&,``8!Q```6(/_U`"`()30%@3`\$___`+TH(0"SF"$F<W\,"!`1*`+`
M("$F<P`$CF3__!"``!(GMH$P#!`,J``@""400/_Y`$"((8!"```00/_V`"`(
M)0P0#84"("`A$$#_\R9S``0F<__\#!`&9`(@("$40``:`$`P(2>V@3".T7\@
M$B``%@``,"&"(@``$$``4B03``$($!%)`"`()0`3$(`"PA`AC%%_(!(@``P`
M`#`A@B(``!!``$@F<P`!#!`-A0(@("$00/_V`!,0@`P0!F0"("`A$$#_\0!`
M,"$`P"`A#!`&1*^F`"@"`"`A#!`&1`!`L"$"PK`A)M8$!`P0!C`"P"`A`$`@
M(0!`B"&/I@`H/!,`0#P%`$`\`@!`)*59S"9G6&@D0EG8KZ(`$`P0!J"OL``4
M`B`@(0P0!F`D!0'`)`/__Q!#`"8`(`@E/!``0@P0!K2.!+U$)$8`8"0$``,,
M$`:X`B`H(1!``"T\`@!"C$2].(ZF```\!0!`)*5::`(@."$,$`9(``"`(30)
M@2P!/4@AC20``(Y#O4`4@P*H`@`0(2>]`6B/OW_LC[Y_Z(^W?^2/MG_@C[5_
MW(^T?]B/LW_4C[)_T(^Q?\R/L'_(`^``"">]?_`($!%1```P(0P0!FP`(`@E
MC$(``"0#`!$00__6/`,`0HZF``",9+TX/`4`0"2E6>`"(#@AKZ(`$`P0!D@`
M`(`A"!`1?C0)@2P,$`:TC@2]1(Q#`'@D`D``,&/P`!1B_\X\`@!"#!`&M(X$
MO40,$`7\C%<`@!;B_\@\`@!"#!`&M(X$O42,0P!X)`(!P#!C`?\48O_!/`(`
M0@P0!C`"P"`A/`0`0"2$670,$`RH`$"`(1!``'8`0"`A#!`&9(ZV````0"@A
M#!`.X`+`("$00`!O`$"P(0P0!D0"P"`A`$"X(2A"``040``-)N3__#P%`$`"
MQ"`A#!`%S"2E6AP40``')`(`!!+B`?D"U[@A@N/_^R0"`"\08@'U`"`()0P0
M$$L`(`@E%$``!SP$`$`"P"`A#!`&3```*"$40`!6`$"H(3P$`$`\!0!`)(18
ML`P0#;`DI5E0#!`&)#P7`$`\!0!`)F=8:";W6V`"`"`A)*5:1`(@,"&OH@`0
MK[<`%`P0!J```*@A)!;__R0>`!$($!(%)G-8:`P0!FP`(`@EC$(``!1>`!$`
M(`@E#!`&)":U``$\!0!``@`@(22E6E0"(#`A`F`X(:^B`!"OM0`4#!`&H*^W
M`!@"`"`A#!`&8"0%`<`05O_L`"`()0P0!=P"("`A)H180`P0#;`"`"@A#!`0
M=@(`("$($!%^-`F!+`P0$':OH@`HCZ(`*`P0!F0`0"`A"!`1?0!`@"$D$0`!
M"!`2(P)@("$`$1"`)Z2!,`""$"&,1'\L$(``#B8Q``$,$`RH`"`()1!`__<`
M(`@E@$,``!!@__0`(`@E#!`&9`!`("$00/_P`$"`(0@0$0N"$0``/!``0`@0
M$1TF$%FD"!`1Q8ZV```D!__N)`;__P!`("$D'@`"/!;__PP0!B"OO@`0-`:!
M,`#=,"$FUW\X`->X(0*@("$"X"@A#!`%T"0&``:3H@!H%$``!).B`&DD`P!#
M$$,!QY.D`&H"H"`A```X(0``,"$,$`8@KZ``$#P#9T4T!X!H`/TX(31C(P&L
MXP`$-`B`<#P#[\TT8ZN)`1U`(:T#``0T"8!X/`.8N@``$"$T8]S^`3U((:SB
M``"M(P`$```0(3P#$#(T&8"`-&-4=@,]R"&M`@`````0(:TB``"O(P`$```0
M(3P#P](T'H"(`]WP(31CX?"O(@`````0(:_#``2OP@``-`2`D#0%@)@T!H#@
M/![__S0'@3```!@A```0(0"=("$`O2@A`-TP(2?>?S@`_3@AK(,`!*R"``"L
MHP`$K*(``*S`````_O`A`J`@(0/`*"$,$`70-`:``!A``'X`0+`A-`B`E#0)
M@)`!'4`A`3U((8T"``"-(P```!8PP``6)\,48`$M`,(P(0#"$"L40`$K-`.`
MG#09@)@T'X"<`SW((0/]^"&/)0``C^(````$.,``%A]"`.,8)0!#&"$`!"="
M`*0H(0!B$"LT"(#@-!^`F`!%$"$!'4`A`_WX(30)@)`T&8"4K^(``(T$```T
M`H"<`3U((0,]R"$`71`AK2```*\F```0@`$(K$,``"0#`$``9!`C`%8H*A"@
M``("P!@A`$`8(30%@*`#I;@A`&`P(0+D("$#P"@A#!`%X*^C`"@T!H#@`-TP
M(8S"``"/HP`H)`<`0`!B$"$41_^[K,(``#0$@&@`G2`A#!`'L*^C`"B/HP`H
M`L.P(P/#*"$JP@!`%$``*"2C`$`FUO_``!9)@@`)$8``8A`AK[8`-*^I`#"O
MH@`L`*"P(0+@$"$FR`!`BL<``(K&``2*Q``(BL,`#)K'``.:Q@`'FL0`"YK#
M``\FU@`0K$<``*Q&``2L1``(K$,`#!;(__(D0@`0-`2`:`"=("$,$`>PKZ4`
M*(^Y`"P6V?_ICZ4`*(^C`#"/I@`T)&(``0`"$8```[&``*(H(0#6L","P#`A
M#!`%X`+@("$T!X#@`/TX(:SV```"H"`A`\`H(0P0!=`T!H``'$#_A`!`L"$,
M$`:\`J`@(30(@)0!'4`AC14``#0)@3``%1#",$(`/R1#``$!/4@A-!F`G`$B
M("$#/<@A)`7_@"AC`#F/-@``H(7_<!!@`,(D1``Y-`6`:`"]*"$D!@`W`*0@
M(0#",",,$`9<```H(30)@-@T&8#9-!Z`V@`61@(`%CP"`!8R`@,]R"$!/4@A
M`]WP(:$H``"C)P``H\8``#0?@-LT!H#<-`>`W30(@-XT"8#?`!4N`@`5'`(`
M%1("`_WX(0#=,"$`_3@A`1U`(0$]2"$T!(!HH_8``*#%``"@XP``H0(``*$U
M```,$`>P`)T@(309@&P#/<@A-!^`?(\G```#_?@A-`*`A#0&@(R/Y````%T0
M(0#=,"$T'X$8C$,```/]^"&,P@``-!Z`=``'-@*CY@```]WP(30?@1F/Q0``
M`_WX(0`']`*C_@``-!^!&P/]^"$T'H$:H^<````'R@(#W?`A-`>!'*/9````
M!<8"`/TX(30>@1X`!;("H/@```/=\"$T&8$=-!^!'S0'@2&CU@````6\`@`$
M?`(#/<@A`_WX(0#]."$T'H$CHS<``*/E``"@[P```]WP(30%@2`T&8$B-!^!
M)#0'@2<`!*X"H\0````$<@(``VX"`+TH(0,]R"$#_?@A-`2!)0#]."$T'H$I
MH+4````#9`(``UH"HRX``*/M````G2`A`]WP(0`"3`(T!8$FH.,``#09@2@T
M'X$J-`.!*P`"5@(``D("H(P```"]*"$#/<@AH\D```/]^"$`?1@A-`2`[#P>
M`$"@JP``HRH``*/H``"@8@````"P(0.DJ"$GWEH\"!`3IR07`!0T!8$8`+TH
M(0"V$"&01@```!8@0`*D("$#P"@A#!`&H";6``$6U__V-`B!%#P%`$`!'4`A
MH0````(`("$DI5HL`B`P(29G6&BOM0`0/`(`0"1"6V`,$`:@KZ(`%`@0$@H`
M(`@E-`B`H`/`*"$($!+1`ZBX(30#@)P`?1@AC&(``#0'@)@`_3@A)$,``8SE
M````8A`K`$4H(0@0$IT`8!`ACK4`!!*@_@H`(`@E#!`&1`*@("$L0P`$%&#^
M!21"__P\!0!``J(@(0P0!<PDI5HD%$#]_P`@""4($!'7`J"P(30>@&@#W?`A
M)`8`/P/$("$``"@A#!`&7`#",",T!(!H#!`'L`"=("$T'X"@-`*`I#0#@*@#
M_?@A`%T0(0!]&"&OX```K$```*Q@```T!("L-`6`L#0&@+0T!X"X-`B`O#0)
M@,`T&8#$-!Z`R#0?@,PT`H#0-`.`U`"=("$`O2@A`-TP(0#]."$!'4`A`3U(
M(0,]R"$#W?`A`_WX(0!=$"$`?1@AK(```*R@``"LP```K.```*T```"M(```
MKR```*_```"OX```K$````@0$R&L8```)`,`012#_CB3HP!K%&+^-I.C`&PD
M`@!(%&+^,Y.C`&TD`@!%%&+^,"0'_\8D!O__`J`@(0P0!B"OO@`0`J`@(0+@
M*"$,$`70)`8`*3P%`$`"`"`A)*5:+`(@,"$F9UAH"!`3MJ^W`!`,$`7X`"`(
M)2>]_[BOL@`H/!(`0HY$O42OOP!$K[X`0*^W`#ROM@`XK[4`-*^T`#"OLP`L
MK[$`)`P0!K2OL``@)`,``3P$`$"@0P/5#!`,J"2$6)000``$)`,`,8!$```0
M@P"N`"`()0P0#\T`(`@E#!`&M(Y$O40\!0!``$`@(22E6KPD!@`!#!`&-"0'
M``L00``T``"((3P4`$*.@\UXC$0`$"AB``(40``KC)4`&"00``$\%P!""!`4
M8SP6`$*,10`0#!`%S`)@("$40``BCH/->"80``$"`Q`J$$``'B8Q``$,$`:T
MCD2]1`!`("$"H"@A`B`P(0P0!I```#@A$$``@`!`\"&,0@``CL7-=(Q#``@`
M$""``*0@(3!C!``48/_GC),```P0!K2.Y+U$C\4```!`("$``#`A#!`&%"0'
M``(`0"@A#!`%S`)@("$00/_@CH/->"1B__\040!3*&,``HY$O40,$`:T/!``
M0CP%`$``0"`A)*5:Q"0&``$,$`8T)`<`!!!``!``0(@A#!`&M(X$O42.(P`0
M/`8`0(QE````0"`A#!`&$"3&6LB.(@`0C$(``(Q#``@\`@!``&(0)!1``$<`
M(`@ECD2]1`P0!K0\$0!"/`4`0`!`("$DI5K0)`8``0P0!C0D!P`$$$``#0!`
M@"$\!`!`#!`,J"2$6$P00`!FCB2]1`P0!K2OH@`<C@,`$(^F`!R,90``#!`&
M$`!`("&.1+U$#!`&M#P3`$*.1+U$#!`&M*!``]4\!`!`K$`%3`P0#*@DA%A`
M$$``-ZYBS7P`0"`A#!`&8"0%`<`00``%)`,`$1!#``,D`___%$,`;#P#`$*/
MOP!$C[X`0(^W`#R/M@`XC[4`-(^T`#"/LP`LC[(`*(^Q`"2/L``@`^``"">]
M`$@48/^M)!```8Y$O40,$`:T)A```0!`("$,$`7D`J`H(8Z"S7@"`A`J%$#_
M]XY$O40($!2$`"`()0P0!K2.!+U$CB,`$`!`("$,$`9\C&4```@0%)Z.1+U$
MCH/->"1B__\44?^6CD2]1`@0%-4H8P`"@$(``1!`_U,`(`@E"!`41``@""4\
M$0!"#!`0SHXDS7000``WKF+-?(X"`!",0@``C$,`"#!C!``08``<`"`()8Q$
M`!`,$`8(CB7-=(X#`!".),UTC&,```!`B"&,8@`(,$($`!!``!R,DP``C&8`
M$#P$`$`DA%KX`F`H(0P0!E0"(#@A#!`&M``@""4\`@!"C@,`$(Q"S72,9```
M#!`.2(Q%```($!2UCD2]1#P"`$(,$`:TC$2]1(X#`!``0"`AC&4`````,"$,
M$`84)`<``@@0%0(`0"`A#!`&M(Y$O42.`P`0```P(8QE````0"`A#!`&%"0'
M``(($!4-`$`P(3P$`$`,$`94)(1:U(QCS70\!`!`C&4``(YFS7PDA%L@#!`&
M5`!`."$GO?_8K[$`(*^_`"0`@(@A#!`/<:^P`!R`1```$(``'B1#``$`0(`A
M)`(`+Q""`!@`(`@E)&,``8!D__\4@/_[`"`()0P0$$L`(`@E$$``#(^_`"02
M(``*`"`()8(B```00``'`@`@(3P%`$`,$`7()*59V!("``H"("`AC[\`)(^Q
M`""/L``<`^``"">]`"@($!5(`&"`(0@0%4P`0(`AC[\`)(^Q`""/L``<"!`-
M'R>]`"@GO?_@K[``&#P0`$*.!+U$K[\`'`P0!K0`(`@E`$`@(0P0!APD!?__
M#!`&M(X$O40\!0!`C[\`'(^P`!@`0"`A)*4S0```,"$($`:H)[T`(```````
M````/!D`0"<Y5@`\'``")YSFX`.9X"&/@H`D`"`()1!```8`(`@EC$<``(^9
M@#P`(`@E`R``"``@""40`/_[```X(0`@""4`(`@E`^``"``@""4\'``")YSF
MF`.9X"$GO?_(K[\`-*^U`#"OM``LK[,`**^R`"2OL0`@K[``'*^\`!"/F8`H
M`("8(0"@H"$#(/@)`,"H(8^\`!``(`@ECY&`+(^2@"P`(`@E`E&0(P`2D(,2
M0``*``"`(8XY```F$``!`F`@(0*`*"$#(/@)`J`P(0(2$"L40/_X)C$`!(^_
M`#2/M0`PC[0`+(^S`"B/L@`DC[$`((^P`!P#X``()[T`.``@""4`(`@E/`(`
M08Q98``GO?_8)`+__Z^_`"2OL0`@$R(`":^P`!P\$`!!)A!@`"01__\#(/@)
M)A#__(X9```7,?_\`"`()8^_`"2/L0`@C[``'`/@``@GO0`H`"`()0`@""4`
M(`@ECYF`$`/@>"$#(/@))!@`;X^9@!`#X'@A`R#X"208`&T`````````````
M````````/!P``B><Y5`#F>`A)[W_X*^_`!ROO``0!!$``0`@""4,$`=\`"`(
M)8^_`!P`(`@E`^``"">]`"`````````````"``$E<R\E<P```"]P<F]C+W-E
M;&8O97AE``!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`<&5R;'AS:2YC
M````26YT97)N86QS.CI005(Z.D)/3U0`````+W!R;V,O)6DO)7,`97AE`"X`
M``!005)?5$5-4`````!005)?4%)/1TY!344`````.@```"5S)7,E<P``+P``
M`%!%4DPU3$E"`````%!%4DQ,24(`4$523#5/4%0`````4$523$E/``!005)?
M24Y)5$E!3$E:140`4$%27U-005=.140`4$%27T-,14%.````4$%27T1%0E5'
M````4$%27T-!0TA%````4$%27T%21T,`````4$%27T%21U9?,```4$%27T=,
M3T)!3%]$14)51P````!005)?1TQ/0D%,7U1-4$1)4@```%!!4E]435!$25(`
M`%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.`````%!!4E]#3$5!
M3CT``#$```!,1%],24)205)97U!!5$@`3$E"4$%42`!,24)205)97U!!5$@`
M````1%E,1%],24)205)97U!!5$@```!32$Q)0E]0051(``!54T52`````%-9
M4U1%30``+W1M<`````!414U01$E2`%1-4`!54T523D%-10`````E<R5S)7,E
M<P````!P87(M`````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C
M=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H``'!A<FP`````+G!A<@`````E
M<R5S8V%C:&4M)7,E<P``)3`R>``````E<R5S=&5M<"TE=25S````)7,E<W1E
M;7`M)74M)74E<P`````E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@
M=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A
M=&EO;BD*``!!4D=6`````!@```!P97)L`````#````!5;F%B;&4@=&\@8W)E
M871E(&-A8VAE(&1I<F5C=&]R>0`````E<SH@97AE8W5T:6]N(&]F("5S(&9A
M:6QE9"`H97)R;F\])6DI"@``)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C
M:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@`````M90``
M+2T```````!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@(```````
M``````````````!!\````````$'/____@```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````_____P````#_____````````````````````````````````````
M````````````_____R,A+W5S<B]B:6XO<&5R;`IE=F%L("=E>&5C("]U<W(O
M8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*("`@(&EF(#`[(",@;F]T(')U
M;FYI;F<@=6YD97(@<V]M92!S:&5L;`H*<&%C:V%G92!?7W!A<E]P;#L*"B,@
M+2TM(%1H:7,@<V-R:7!T(&UU<W0@;F]T('5S92!A;GD@;6]D=6QE<R!A="!C
M;VUP:6QE('1I;64@+2TM"B,@=7-E('-T<FEC=#L*"B-L:6YE(#$U.`H*;7D@
M*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92D["D5.1"![(&EF("@D
M14Y6>U!!4E]#3$5!3GTI('L*("`@(')E<75I<F4@1FEL93HZ5&5M<#L*("`@
M(')E<75I<F4@1FEL93HZ0F%S96YA;64["B`@("!R97%U:7)E($9I;&4Z.E-P
M96,["B`@("!M>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H
M)'!A<E]T96UP*3L*("`@(&]U=',H<7%[4F5M;W9I;F<@9FEL97,@:6X@(B1P
M87)?=&5M<")]*3L*("`@($9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H
M("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PH@("`@<FUD
M:7(@)'!A<E]T96UP.PH@("`@(R!$;VXG="!R96UO=F4@=&]P9&ER(&)E8V%U
M<V4@=&AI<R!C875S97,@82!R86-E('=I=&@@;W1H97(@87!P<PH@("`@(R!T
M:&%T(&%R92!T<GEI;F<@=&\@<W1A<G0N"@H@("`@:68@*"UD("1P87)?=&5M
M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["B`@("`@("`@(R!3;VUE=&AI;F<@
M=V5N="!W<F]N9R!U;FQI;FMI;F<@=&AE('1E;7!O<F%R>2!D:7)E8W1O<GDN
M("!4:&ES"B`@("`@("`@(R!T>7!I8V%L;'D@:&%P<&5N<R!O;B!P;&%T9F]R
M;7,@=&AA="!D:7-A;&QO=R!U;FQI;FMI;F<@<VAA<F5D"B`@("`@("`@(R!L
M:6)R87)I97,@86YD(&5X96-U=&%B;&5S('1H870@87)E(&EN('5S92X@56YL
M:6YK('=I=&@@82!B86-K9W)O=6YD"B`@("`@("`@(R!S:&5L;"!C;VUM86YD
M('-O('1H92!F:6QE<R!A<F4@;F\@;&]N9V5R(&EN('5S92!B>2!T:&ES('!R
M;V-E<W,N"B`@("`@("`@(R!$;VXG="!D;R!A;GET:&EN9R!O;B!7:6YD;W=S
M(&)E8V%U<V4@;W5R('!A<F5N="!P<F]C97-S('=I;&P*("`@("`@("`C('1A
M:V4@8V%R92!O9B!C;&5A;FEN9R!T:&EN9W,@=7`N"@H@("`@("`@(&UY("1T
M;7`@/2!N97<@1FEL93HZ5&5M<"@*("`@("`@("`@("`@5$5-4$Q!5$4@/3X@
M)W1M<%A86%A8)RP*("`@("`@("`@("`@1$E2(#T^($9I;&4Z.D)A<V5N86UE
M.CID:7)N86UE*"1T;W!D:7(I+`H@("`@("`@("`@("!3549&25@@/3X@)RYC
M;60G+`H@("`@("`@("`@("!53DQ)3DL@/3X@,"P*("`@("`@("`I.PH*("`@
M("`@("!P<FEN="`D=&UP("(C(2]B:6XO<V@*>#TQ.R!W:&EL92!;(%PD>"`M
M;'0@,3`@73L@9&\*("`@<FT@+7)F("<D<&%R7W1E;7`G"B`@(&EF(%L@7"$@
M+60@)R1P87)?=&5M<"<@73L@=&AE;@H@("`@("`@8G)E86L*("`@9FD*("`@
M<VQE97`@,0H@("!X/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R(@+B`D=&UP
M+3YF:6QE;F%M92`N("(G"B(["B`@("`@("`@("`@(&-H;6]D(#`W,#`L)'1M
M<"T^9FEL96YA;64["B`@("`@("`@;7D@)&-M9"`]("1T;7`M/F9I;&5N86UE
M("X@)R`^+V1E=B]N=6QL(#(^)C$@)B<["B`@("`@("`@8VQO<V4@)'1M<#L*
M("`@("`@("!S>7-T96TH)&-M9"D["B`@("`@("`@;W5T<RAQ<2A3<&%W;F5D
M(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("D*("`@
M("`@("`@("`@("X@)'1M<"T^9FEL96YA;64I.PH@("`@?0I]('T*"D)%1TE.
M('L*("`@($EN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT
M97)N86QS.CI005(Z.D)/3U0["@H@("`@979A;"!["@I?<&%R7VEN:71?96YV
M*"D["@II9B`H97AI<W1S("1%3E9[4$%27T%21U9?,'T@86YD("1%3E9[4$%2
M7T%21U9?,'T@*2!["B`@("!`05)'5B`](&UA<"`D14Y6>R)005)?05)'5E\D
M7R)]+"`H,2`N+B`D14Y6>U!!4E]!4D=#?2`M(#$I.PH@("`@)#`@/2`D14Y6
M>U!!4E]!4D=67S!].PI]"F5L<V4@>PH@("`@9F]R("AK97ES("5%3E8I('L*
M("`@("`@("!D96QE=&4@)$5.5GLD7WT@:68@+UY005)?05)'5E\O.PH@("`@
M?0I]"@IM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PH*(R!F:7@@)'!R
M;V=N86UE(&EF(&EN=F]K960@9G)O;2!0051("FUY("5#;VYF:6<@/2`H"B`@
M("!P871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG
M*2P*("`@(%]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\
M8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"B`@("!?9&5L:6T@("`@("`]/B`H
M)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PH*7W-E=%]P
M<F]G;F%M92@I.PI?<V5T7W!A<E]T96UP*"D["@HC($UA9VEC('-T<FEN9R!C
M:&5C:VEN9R!A;F0@97AT<F%C=&EN9R!B=6YD;&5D(&UO9'5L97,@>WM["FUY
M("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI["B`@("!L;V-A;"`D4TE'>U]?
M5T%23E]??2`]('-U8B![?3L*"B`@("`C($-H96-K(&9I;&4@='EP92P@9V5T
M('-T87)T(&]F(&1A=&$@<V5C=&EO;B![>WL*("`@(&]P96X@7T9(+"`G/"<L
M("1P<F]G;F%M92!O<B!L87-T.PH@("`@8FEN;6]D92A?1D@I.PH*("`@(&UY
M("1B=68["B`@("!S965K(%]&2"P@+3@L(#(["B`@("!R96%D(%]&2"P@)&)U
M9BP@.#L*("`@(&QA<W0@=6YL97-S("1B=68@97$@(EQN4$%2+G!M7&XB.PH*
M("`@('-E96L@7T9(+"`M,3(L(#(["B`@("!R96%D(%]&2"P@)&)U9BP@-#L*
M("`@('-E96L@7T9(+"`M,3(@+2!U;G!A8VLH(DXB+"`D8G5F*2P@,CL*("`@
M(')E860@7T9(+"`D8G5F+"`T.PH*("`@("1D871A7W!O<R`]("AT96QL(%]&
M2"D@+2`T.PH@("`@(R!]?7T*"B`@("`C($5X=')A8W1I;F<@96%C:"!F:6QE
M(&EN=&\@;65M;W)Y('M[>PH@("`@;7D@)7)E<75I<F5?;&ES=#L*("`@('=H
M:6QE("@D8G5F(&5Q(")&24Q%(BD@>PH@("`@("`@(')E860@7T9(+"`D8G5F
M+"`T.PH@("`@("`@(')E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F
M*3L*"B`@("`@("`@;7D@)&9U;&QN86UE(#T@)&)U9CL*("`@("`@("!O=71S
M*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN*2D["B`@("`@("`@
M;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I
M(#\@)#$@.B!U;F1E9CL*("`@("`@("!M>2`H)&)A<V5N86UE+"`D97AT*2`]
M("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["@H@("`@("`@(')E
M860@7T9(+"`D8G5F+"`T.PH@("`@("`@(')E860@7T9(+"`D8G5F+"!U;G!A
M8VLH(DXB+"`D8G5F*3L*"B`@("`@("`@:68@*&1E9FEN960H)&5X="D@86YD
M("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["B`@("`@("`@("`@
M(&UY("@D;W5T+"`D9FEL96YA;64I(#T@7W1E;7!F:6QE*"1E>'0L("1C<F,I
M.PH@("`@("`@("`@("!I9B`H)&]U="D@>PH@("`@("`@("`@("`@("`@8FEN
M;6]D92@D;W5T*3L*("`@("`@("`@("`@("`@('!R:6YT("1O=70@)&)U9CL*
M("`@("`@("`@("`@("`@(&-L;W-E("1O=70["B`@("`@("`@("`@("`@("!C
M:&UO9"`P-S4U+"`D9FEL96YA;64["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N
M86UE.PH@("`@("`@("`@("`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE
M;F%M97T@/2`D9G5L;&YA;64["B`@("`@("`@?0H@("`@("`@(&5L<VEF("@@
M)&9U;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!
M4E]414U0?2`I('L*("`@("`@("`@("`@(R!S:&]U;&0@8F4@;6]V960@=&\@
M7W1E;7!F:6QE*"D*("`@("`@("`@("`@;7D@)&9I;&5N86UE(#T@(B1%3E9[
M4$%27U1%35!]+R1B87-E;F%M921E>'0B.PH@("`@("`@("`@("!O=71S*")3
M2$Q)0CH@)&9I;&5N86UE7&XB*3L*("`@("`@("`@("`@;W!E;B!M>2`D;W5T
M+"`G/B<L("1F:6QE;F%M92!O<B!D:64@)"$["B`@("`@("`@("`@(&)I;FUO
M9&4H)&]U="D["B`@("`@("`@("`@('!R:6YT("1O=70@)&)U9CL*("`@("`@
M("`@("`@8VQO<V4@)&]U=#L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@
M("`@("`@("`@("1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2`]"B`@("`@("`@
M("`@("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PH@
M("`@("`@("`@("`@("`@8G5F(#T^("1B=68L"B`@("`@("`@("`@("`@("!C
M<F,@/3X@)&-R8RP*("`@("`@("`@("`@("`@(&YA;64@/3X@)&9U;&QN86UE
M+`H@("`@("`@("`@("!].PH@("`@("`@('T*("`@("`@("!R96%D(%]&2"P@
M)&)U9BP@-#L*("`@('T*("`@(",@?7U]"@H@("`@;&]C86P@0$E.0R`]("AS
M=6(@>PH@("`@("`@(&UY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*"B`@("`@
M("`@<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PH*("`@("`@
M("!M>2`D9FEL96YA;64@/2!D96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE
M?2!\?"!D;R!["B`@("`@("`@("`@(&UY("1K97D["B`@("`@("`@("`@(&9O
M<F5A8V@@*&ME>7,@)7)E<75I<F5?;&ES="D@>PH@("`@("`@("`@("`@("`@
M;F5X="!U;FQE<W,@+UQ1)&UO9'5L95Q%)"\["B`@("`@("`@("`@("`@("`D
M:V5Y(#T@)%\[(&QA<W0["B`@("`@("`@("`@('T*("`@("`@("`@("`@9&5L
M971E("1R97%U:7)E7VQI<W1[)&ME>7T@:68@9&5F:6YE9"@D:V5Y*3L*("`@
M("`@("!](&]R(')E='5R;CL*"B`@("`@("`@)$E.0WLD;6]D=6QE?2`]("(O
M;&]A9&5R+R1F:6QE;F%M92\D;6]D=6QE(CL*"B`@("`@("`@:68@*"1%3E9[
M4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*("`@
M("`@("`@("`@;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I
M92`D(3L*("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@("!P
M<FEN="`D9F@@)&9I;&5N86UE+3Y[8G5F?3L*("`@("`@("`@("`@<V5E:R@D
M9F@L(#`L(#`I.PH@("`@("`@("`@("!R971U<FX@)&9H.PH@("`@("`@('T*
M("`@("`@("!E;'-E('L*("`@("`@("`@("`@;7D@*"1O=70L("1N86UE*2`]
M(%]T96UP9FEL92@G+G!M)RP@)&9I;&5N86UE+3Y[8W)C?2D["B`@("`@("`@
M("`@(&EF("@D;W5T*2!["B`@("`@("`@("`@("`@("!B:6YM;V1E*"1O=70I
M.PH@("`@("`@("`@("`@("`@<')I;G0@)&]U="`D9FEL96YA;64M/GMB=69]
M.PH@("`@("`@("`@("`@("`@8VQO<V4@)&]U=#L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!O<&5N(&UY("1F:"P@)SPG+"`D;F%M92!O<B!D:64@)"$[
M"B`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@("`@<F5T=7)N
M("1F:#L*("`@("`@("!]"@H@("`@("`@(&1I92`B0F]O='-T<F%P<&EN9R!F
M86EL960Z(&-A;FYO="!F:6YD("1M;V1U;&4A7&XB.PH@("`@?2P@0$E.0RD[
M"@H@("`@(R!.;W<@;&]A9"!A;&P@8G5N9&QE9"!F:6QE<R![>WL*"B`@("`C
M(&EN:71I86QI>F4@<VAA<F5D(&]B:F5C="!P<F]C97-S:6YG"B`@("!R97%U
M:7)E(%A33&]A9&5R.PH@("`@<F5Q=6ER92!005(Z.DAE879Y.PH@("`@<F5Q
M=6ER92!#87)P.CI(96%V>3L*("`@(')E<75I<F4@17AP;W)T97(Z.DAE879Y
M.PH@("`@4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PH*("`@(",@
M;F]W(&QE="=S('1R>2!G971T:6YG(&AE;'!E<B!M;V1U;&5S(&9R;VT@=VET
M:&EN"B`@("!R97%U:7)E($E/.CI&:6QE.PH*("`@(",@;&]A9"!R97-T(&]F
M('1H92!G<F]U<"!I;@H@("`@=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T
M(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*("`@("`@("`C;&]C86P@)$E.
M0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH@
M("`@("`@('5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]
M?B`O0E-$4$%.+RD@>PH@("`@("`@("`@("`C(')E<75I<F4@;6]D=6QE<RP@
M9&\@;W1H97(@97AE8W5T86)L92!F:6QE<PH@("`@("`@("`@("!I9B`H)&9I
M;&5N86UE(#U^("]<+G!M8S\D+VDI('L*("`@("`@("`@("`@("`@(')E<75I
M<F4@)&9I;&5N86UE.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<V4@
M>PH@("`@("`@("`@("`@("`@(R!3:VEP($%C=&EV95-T871E)W,@<VET96-U
M<W1O;6EZ92YP;"!F:6QE.@H@("`@("`@("`@("`@("`@9&\@)&9I;&5N86UE
M('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["B`@
M("`@("`@("`@('T*("`@("`@("!]"B`@("`@("`@9&5L971E("1R97%U:7)E
M7VQI<W1[)&9I;&5N86UE?3L*("`@('T*"B`@("`C('U]?0H*("`@(&QA<W0@
M=6YL97-S("1B=68@97$@(E!+7#`P,UPP,#0B.PH@("`@)'-T87)T7W!O<R`]
M("AT96QL(%]&2"D@+2`T.PI]"B,@?7U]"@HC($%R9W5M96YT('!R;V-E<W-I
M;F<@>WM["FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F
M:"P@)&-A8VAE7VYA;64I.PH*9&5L971E("1%3E9[4$%27T%04%]2155317T[
M(",@<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI
M"@HD<75I970@/2`P('5N;&5S<R`D14Y6>U!!4E]$14)51WT["B,@1&]N)W0@
M<W=A;&QO=R!A<F=U;65N=',@9F]R(&-O;7!I;&5D(&5X96-U=&%B;&5S('=I
M=&AO=70@+2UP87(M;W!T:6]N<PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=6
M6S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*("`@(&UY("5D
M:7-T7V-M9"`]('%W*`H@("`@("`@('`@("!B;&EB7W1O7W!A<@H@("`@("`@
M(&D@("!I;G-T86QL7W!A<@H@("`@("`@('4@("!U;FEN<W1A;&Q?<&%R"B`@
M("`@("`@<R`@('-I9VY?<&%R"B`@("`@("`@=B`@('9E<FEF>5]P87(*("`@
M("D["@H@("`@(R!I9B!T:&4@87!P(&ES(&EN=F]K960@87,@(F%P<&YA;64@
M+2UP87(M;W!T:6]N<R`M+7)E=7-E(%!23T=204T@0%!23T=?05)'5B(L"B`@
M("`C('5S92!T:&4@87!P('1O(')U;B!T:&4@9VEV96X@<&5R;"!C;V1E(&EN
M<W1E860@;V8@86YY=&AI;F<@9G)O;2!T:&4*("`@(",@87!P(&ET<V5L9B`H
M8G5T('-T:6QL('-E="!U<"!T:&4@;F]R;6%L(&%P<"!E;G9I<F]N;65N="!A
M;F0@0$E.0RD*("`@(&EF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U
M<V4G*2!["B`@("`@("`@<VAI9G0@0$%21U8["B`@("`@("`@)$5.5GM005)?
M05!07U)%55-%?2`]('-H:69T($!!4D=6.PH@("`@?0H@("`@96QS92![(",@
M;F]R;6%L('!A<FP@8F5H879I;W5R"@H@("`@("`@(&UY($!A9&1?=&]?:6YC
M.PH@("`@("`@('=H:6QE("A`05)'5BD@>PH@("`@("`@("`@("`D05)'5ELP
M72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PH*("`@
M("`@("`@("`@:68@*"0Q(&5Q("=))RD@>PH@("`@("`@("`@("`@("`@<'5S
M:"!`861D7W1O7VEN8RP@)#(["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M96QS:68@*"0Q(&5Q("=-)RD@>PH@("`@("`@("`@("`@("`@979A;"`B=7-E
M("0R(CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@
M)T$G*2!["B`@("`@("`@("`@("`@("!U;G-H:69T($!P87)?87)G<RP@)#([
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=/)RD@
M>PH@("`@("`@("`@("`@("`@)&]U="`]("0R.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@(&5L<VEF("@D,2!E<2`G8B<I('L*("`@("`@("`@("`@("`@
M("1B=6YD;&4@/2`G<VET92<["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M96QS:68@*"0Q(&5Q("=")RD@>PH@("`@("`@("`@("`@("`@)&)U;F1L92`]
M("=A;&PG.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E
M<2`G<2<I('L*("`@("`@("`@("`@("`@("1Q=6EE="`](#$["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=,)RD@>PH@("`@("`@
M("`@("`@("`@;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92`B6%A8.B!#
M86YN;W0@;W!E;B!L;V<Z("0A(CL*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!E;'-I9B`H)#$@97$@)U0G*2!["B`@("`@("`@("`@("`@("`D8V%C:&5?
M;F%M92`]("0R.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!S:&EF="A`
M05)'5BD["@H@("`@("`@("`@("!I9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD
M,7TI('L*("`@("`@("`@("`@("`@(&1E;&5T92`D14Y6>R=005)?5$5-4"=]
M.PH@("`@("`@("`@("`@("`@:6YI=%]I;F,H*3L*("`@("`@("`@("`@("`@
M(')E<75I<F4@4$%2.CI$:7-T.PH@("`@("`@("`@("`@("`@)GLB4$%2.CI$
M:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B`@("`@("`@("`@("`@("`F
M>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PH@("`@("`@("`@
M("`@("`@97AI=#L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@
M=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*("`@('T*?0H*(R!86%@@+2T@
M861D("TM<&%R+61E8G5G('-U<'!O<G0A"@HC('U]?0H*(R!/=71P=70@;6]D
M92`H+4\I(&AA;F1L:6YG('M[>PII9B`H)&]U="D@>PH@("`@>PH@("`@("`@
M("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N92`G
M35-7:6XS,B<["B`@("`@("`@<F5Q=6ER92!)3SHZ1FEL93L*("`@("`@("!R
M97%U:7)E($%R8VAI=F4Z.EII<#L*("`@('T*"B`@("!M>2`D<&%R(#T@<VAI
M9G0H0$%21U8I.PH@("`@;7D@)'II<#L*"@H@("`@:68@*&1E9FEN960@)'!A
M<BD@>PH@("`@("`@(&]P96X@;7D@)&9H+"`G/"<L("1P87(@;W(@9&EE(")#
M86YN;W0@9FEN9"`G)'!A<B<Z("0A(CL*("`@("`@("!B:6YM;V1E*"1F:"D[
M"B`@("`@("`@8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*"B`@("`@("`@)'II
M<"`]($%R8VAI=F4Z.EII<"T^;F5W.PH@("`@("`@("@@)'II<"T^<F5A9$9R
M;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/
M2R@I("D*("`@("`@("`@("`@;W(@9&EE(")296%D("<D<&%R)R!E<G)O<CH@
M)"$B.PH@("`@?0H*"B`@("!M>2`E96YV(#T@9&\@>PH@("`@("`@(&EF("@D
M>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I
M*2!["B`@("`@("`@("`@("1M971A(#U^(',O+BI><&%R.B0O+VUS.PH@("`@
M("`@("`@("`D;65T82`]?B!S+UY<4RXJ+R]M<SL*("`@("`@("`@("`@)&UE
M=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PH@("`@("`@('T*("`@('T[
M"@H@("`@(R!/<&5N(&EN<'5T(&%N9"!O=71P=70@9FEL97,@>WM["B`@("!L
M;V-A;"`D+R`](%PT.PH*("`@(&EF("AD969I;F5D("1P87(I('L*("`@("`@
M("!O<&5N(%!!4BP@)SPG+"`D<&%R(&]R(&1I92`B)"$Z("1P87(B.PH@("`@
M("`@(&)I;FUO9&4H4$%2*3L*("`@("`@("!D:64@(B1P87(@:7,@;F]T(&$@
M4$%2(&9I;&4B('5N;&5S<R`\4$%2/B!E<2`B4$M<,#`S7#`P-"(["B`@("!]
M"@H@("`@0W)E871E4&%T:"@D;W5T*2`["B`@("`*("`@(&UY("1F:"`]($E/
M.CI&:6QE+3YN97<H"B`@("`@("`@)&]U="P*("`@("`@("!)3SHZ1FEL93HZ
M3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ
M3U]44E5.0R@I+`H@("`@("`@(#`W-S<L"B`@("`I(&]R(&1I92`D(3L*("`@
M(&)I;FUO9&4H)&9H*3L*"B`@("`D+R`]("AD969I;F5D("1D871A7W!O<RD@
M/R!<)&1A=&%?<&]S(#H@=6YD968["B`@("!S965K(%]&2"P@,"P@,#L*("`@
M(&UY("1L;V%D97(@/2!S8V%L87(@/%]&2#X["B`@("!I9B`H(21%3E9[4$%2
M7U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*
M("`@("`@("!R97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*("`@("`@
M("!005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1L;V%D97(L
M("0P*0H@("`@?0H@("`@9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N
M=BD@>PH@("`@("`@(&UY("1V86P@/2`D96YV>R1K97E](&]R(&YE>'0["B`@
M("`@("`@)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\["B`@
M("`@("`@;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B
M7U\B.PH@("`@("`@(&UY("1S970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(]
M)'9A;"(["B`@("`@("`@)&QO861E<B`]?B!S>R1M86=I8R@@*RE]>PH@("`@
M("`@("`@("`D;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG=&@H)#$I("T@
M;&5N9W1H*"1S970I*2D*("`@("`@("!]96<["B`@("!]"B`@("`D9F@M/G!R
M:6YT*"1L;V%D97(I.PH@("`@)"\@/2!U;F1E9CL*("`@(",@?7U]"@H@("`@
M(R!7<FET92!B=6YD;&5D(&UO9'5L97,@>WM["B`@("!I9B`H)&)U;F1L92D@
M>PH@("`@("`@(')E<75I<F4@4$%2.CI(96%V>3L*("`@("`@("!005(Z.DAE
M879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["B`@("`@("`@:6YI=%]I;F,H*3L*
M"B`@("`@("`@<F5Q=6ER95]M;V1U;&5S*"D["@H@("`@("`@(&UY($!I;F,@
M/2!S;W)T('L*("`@("`@("`@("`@;&5N9W1H*"1B*2`\/3X@;&5N9W1H*"1A
M*0H@("`@("`@('T@9W)E<"!["B`@("`@("`@("`@("$O0E-$4$%.+PH@("`@
M("`@('T@9W)E<"!["B`@("`@("`@("`@("@D8G5N9&QE(&YE("=S:71E)RD@
M;W(*("`@("`@("`@("`@*"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB
M97AP?2!A;F0*("`@("`@("`@("`@("1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP
M<FEV;&EB97AP?2D["B`@("`@("`@?2!`24Y#.PH*("`@("`@("`C($9I;&4@
M97AI<W1S('1E<W0@861D960@=&\@9FEX(%)4(",T,3<Y,#H*("`@("`@("`C
M($9U;FYY+"!N;VXM97AI<W1I;F<@96YT<GD@:6X@7SPN+BXN875T;R]#;VUP
M<F5S<R]287<O6FQI8B]A=71O<W!L:70N:7@N"B`@("`@("`@(R!4:&ES(&ES
M(&$@8F%N9"UA:60@9FEX('=I=&@@;F\@9&5E<&5R(&=R87-P(&]F('1H92!I
M<W-U92X*("`@("`@("`C(%-O;65B;V1Y('!L96%S92!G;R!T:')O=6=H('1H
M92!P86EN(&]F('5N9&5R<W1A;F1I;F<@=VAA="=S(&AA<'!E;FEN9RP*("`@
M("`@("`C($D@9F%I;&5D+B`M+2!3=&5F9F5N"B`@("`@("`@;7D@)69I;&5S
M.PH@("`@("`@("]>7SPH+BLI)"\@86YD("UE("0Q(&%N9"`D9FEL97-[)#%]
M*RL@9F]R(&ME>7,@)3HZ.PH@("`@("`@("1F:6QE<WLD7WTK*R!F;W(@=F%L
M=65S("5)3D,["@H@("`@("`@(&UY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N
M9FEG>VQI8E]E>'1].PH@("`@("`@(&UY("5W<FET=&5N.PH*("`@("`@("!F
M;W)E86-H("AS;W)T(&ME>7,@)69I;&5S*2!["B`@("`@("`@("`@(&UY("@D
M;F%M92P@)&9I;&4I.PH*("`@("`@("`@("`@9F]R96%C:"!M>2`D9&ER("A`
M:6YC*2!["B`@("`@("`@("`@("`@("!I9B`H)&YA;64@/2`D4$%2.CI(96%V
M>3HZ1G5L;$-A8VAE>R1??2D@>PH@("`@("`@("`@("`@("`@("`@("1F:6QE
M(#T@)%\["B`@("`@("`@("`@("`@("`@("`@;&%S=#L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@(&5L<VEF("@O7BA<421D:7)<15PO*"XJ
M6UY#8UTI*5Q:+VDI('L*("`@("`@("`@("`@("`@("`@("`H)&9I;&4L("1N
M86UE*2`]("@D,2P@)#(I.PH@("`@("`@("`@("`@("`@("`@(&QA<W0["B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!E;'-I9B`H;2%>+VQO
M861E<B];7B]=*R\H+BI;7D-C72E<6B$I('L*("`@("`@("`@("`@("`@("`@
M("!I9B`H;7D@)')E9B`]("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD,7TI
M('L*("`@("`@("`@("`@("`@("`@("`@("`@*"1F:6QE+"`D;F%M92D@/2`H
M)')E9BP@)#$I.PH@("`@("`@("`@("`@("`@("`@("`@("!L87-T.PH@("`@
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@("`@("!E;'-I9B`H
M+68@(B1D:7(O)#$B*2!["B`@("`@("`@("`@("`@("`@("`@("`@("@D9FEL
M92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PH@("`@("`@("`@("`@("`@
M("`@("`@("!L87-T.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@('T*("`@("`@("`@("`@?0H*("`@("`@("`@("`@;F5X="!U;FQE
M<W,@9&5F:6YE9"`D;F%M92!A;F0@;F]T("1W<FET=&5N>R1N86UE?2LK.PH@
M("`@("`@("`@("!N97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O
M7"Y<421L:6)?97AT7$4D+SL*("`@("`@("`@("`@;W5T<R@@:F]I;B`B(BP*
M("`@("`@("`@("`@("`@('%Q*%!A8VMI;F<@(BDL(')E9B`D9FEL92`_("1F
M:6QE+3Y[;F%M97T@.B`D9FEL92P*("`@("`@("`@("`@("`@('%Q*"(N+BXI
M"B`@("`@("`@("`@("D["@H@("`@("`@("`@("!M>2`D8V]N=&5N=#L*("`@
M("`@("`@("`@:68@*')E9B@D9FEL92DI('L*("`@("`@("`@("`@("`@("1C
M;VYT96YT(#T@)&9I;&4M/GMB=69].PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@;W!E;B!&24Q%+"`G/"<L("1F
M:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B.PH@("`@("`@("`@
M("`@("`@8FEN;6]D92A&24Q%*3L*("`@("`@("`@("`@("`@("1C;VYT96YT
M(#T@/$9)3$4^.PH@("`@("`@("`@("`@("`@8VQO<V4@1DE,13L*"B`@("`@
M("`@("`@("`@("!005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH
M7"1C;VYT96YT+"`D9FEL92D*("`@("`@("`@("`@("`@("`@("!I9B`A)$5.
M5GM005)?5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD
M+VD["@H@("`@("`@("`@("`@("`@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N
M="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@(&]U=',H<7$H5W)I='1E;B!A<R`B)&YA
M;64B*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H(D9)3$4B*3L*("`@("`@
M("`@("`@)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI
M*3L*("`@("`@("`@("`@)&9H+3YP<FEN="AS<')I;G1F*`H@("`@("`@("`@
M("`@("`@(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D
M8V]N=&5N="DL("1N86UE"B`@("`@("`@("`@("DI.PH@("`@("`@("`@("`D
M9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D["B`@("`@
M("`@("`@("1F:"T^<')I;G0H)&-O;G1E;G0I.PH@("`@("`@('T*("`@('T*
M("`@(",@?7U]"@H@("`@(R!.;W<@=W)I=&4@;W5T('1H92!005(@86YD(&UA
M9VEC('-T<FEN9W,@>WM["B`@("`D>FEP+3YW<FET951O1FEL94AA;F1L92@D
M9F@I(&EF("1Z:7`["@H@("`@)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE
M7VYA;64L(#`L(#0P.PH@("`@:68@*"$D8V%C:&5?;F%M92!A;F0@;7D@)&UT
M:6UE(#T@*'-T870H)&]U="DI6SE=*2!["B`@("`@("`@;7D@)&-T>"`](&5V
M86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I
M('T*("`@("`@("`@("`@?'P@979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q
M.R!$:6=E<W0Z.E-(03$M/FYE=R!]"B`@("`@("`@("`@('Q\(&5V86P@>R!R
M97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["@H@("`@
M("`@(",@5V]R:V%R;W5N9"!F;W(@8G5G(&EN($1I9V5S=#HZ4TA!(#4N,S@@
M86YD(#4N,SD*("`@("`@("!M>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I
M9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*("`@("`@("!I9B`H)'-H85]V
M97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2![
M"B`@("`@("`@("`@("1C='@M/F%D9&9I;&4H)&]U="P@(F(B*2!I9B`H)&-T
M>"D["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@("!I9B`H
M)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)&]U="(I*2!["B`@("`@("`@("`@
M("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@("`@("`D8W1X+3YA9&1F
M:6QE*"1F:"D["B`@("`@("`@("`@("`@("!C;&]S92@D9F@I.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H*("`@("`@("`D8V%C:&5?;F%M92`]("1C='@@
M/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64["B`@("!]"B`@("`D8V%C:&5?
M;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N86UE*3L*("`@
M("1C86-H95]N86UE("X](")#04-(12(["B`@("`D9F@M/G!R:6YT*"1C86-H
M95]N86UE*3L*("`@("1F:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M
M(&QE;F=T:"@D;&]A9&5R*2DI.PH@("`@)&9H+3YP<FEN="@B7&Y005(N<&U<
M;B(I.PH@("`@)&9H+3YC;&]S93L*("`@(&-H;6]D(#`W-34L("1O=70["B`@
M("`C('U]?0H*("`@(&5X:70["GT*(R!]?7T*"B,@4')E<&%R92`D<')O9VYA
M;64@:6YT;R!005(@9FEL92!C86-H92![>WL*>PH@("`@;&%S="!U;FQE<W,@
M9&5F:6YE9"`D<W1A<G1?<&]S.PH*("`@(%]F:7A?<')O9VYA;64H*3L*"B`@
M("`C($YO=R!L;V%D('1H92!005(@9FEL92!A;F0@<'5T(&ET(&EN=&\@4$%2
M.CI,:6)#86-H92![>WL*("`@(')E<75I<F4@4$%2.PH@("`@4$%2.CI(96%V
M>3HZ7VEN:71?9'EN86QO861E<B@I.PH*"B`@("!["B`@("`@("`@(VQO8V%L
M("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R
M)SL*("`@("`@("!R97%U:7)E($9I;&4Z.D9I;F0["B`@("`@("`@<F5Q=6ER
M92!!<F-H:79E.CI::7`["B`@("!]"B`@("!M>2`D>FEP(#T@07)C:&EV93HZ
M6FEP+3YN97<["B`@("!M>2`D9F@@/2!)3SHZ1FEL92T^;F5W.PH@("`@)&9H
M+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE("(D(3H@)$`B.PH@
M("`@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]
M/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D(3H@)$`B.PH*("`@
M('!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B`@("`D4$%2.CI,:6)#86-H
M97LD<')O9VYA;65](#T@)'II<#L*"B`@("`D<75I970@/2`A)$5.5GM005)?
M1$5"54=].PH@("`@;W5T<RAQ<2A<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM0
M05)?5$5-4'TB*2D["@H@("`@:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI
M('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"B`@("`@("`@9F]R
M96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*("`@("`@("`@
M("`@;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*("`@("`@("`@("`@
M;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64["B`@("`@("`@
M("`@(&YE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PH@("`@("`@("`@
M("`@("`@7@H@("`@("`@("`@("`@("`@+S]S:&QI8B\*("`@("`@("`@("`@
M("`@("@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PH@("`@("`@("`@
M("`@("`@*#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PH@("`@("`@
M("`@("`@("`@*%M>+UTK*0H@("`@("`@("`@("`@("`@)`H@("`@("`@("`@
M("!]>#L*("`@("`@("`@("`@;7D@)&5X=')A8W1?;F%M92`]("0Q.PH@("`@
M("`@("`@("!M>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D
M14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["B`@("`@("`@("`@(&EF
M("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S
M<V5D4VEZ92@I*2!["B`@("`@("`@("`@("`@("!O=71S*'%Q*%-K:7!P:6YG
M("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D
M9&5S=%]N86UE(BDI.PH@("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@
M("`@("`@;W5T<RAQ<2A%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D
M9&5S=%]N86UE(BDI.PH@("`@("`@("`@("`@("`@)&UE;6)E<BT^97AT<F%C
M=%1O1FEL94YA;65D*"1D97-T7VYA;64I.PH@("`@("`@("`@("`@("`@8VAM
M;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*("`@("`@
M("`@("`@?0H@("`@("`@('T*("`@('T*("`@(",@?7U]"GT*(R!]?7T*"B,@
M268@=&AE<F4G<R!N;R!M86EN+G!L('1O(')U;BP@<VAO=R!U<V%G92![>WL*
M=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["B`@("!D:64@
M/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@
M6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN
M<&P@70H@("`@("`@)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*
M+@H@("`@)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S
M:&EF="A`05)'5BD["GT*(R!]?7T*"G-U8B!#<F5A=&50871H('L*("`@(&UY
M("@D;F%M92D@/2!`7SL*("`@(`H@("`@<F5Q=6ER92!&:6QE.CI"87-E;F%M
M93L*("`@(&UY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A
M<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*("`@(`H@("`@
M<F5Q=6ER92!&:6QE.CI0871H.PH@("`@"B`@("!&:6QE.CI0871H.CIM:W!A
M=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET
M:"!E<G)O<@I]"@IS=6(@<F5Q=6ER95]M;V1U;&5S('L*("`@("-L;V-A;"`D
M24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<[
M"@H@("`@<F5Q=6ER92!L:6(["B`@("!R97%U:7)E($1Y;F%,;V%D97(["B`@
M("!R97%U:7)E(&EN=&5G97(["B`@("!R97%U:7)E('-T<FEC=#L*("`@(')E
M<75I<F4@=V%R;FEN9W,["B`@("!R97%U:7)E('9A<G,["B`@("!R97%U:7)E
M($-A<G`["B`@("!R97%U:7)E($-A<G`Z.DAE879Y.PH@("`@<F5Q=6ER92!%
M<G)N;SL*("`@(')E<75I<F4@17AP;W)T97(Z.DAE879Y.PH@("`@<F5Q=6ER
M92!%>'!O<G1E<CL*("`@(')E<75I<F4@1F-N=&P["B`@("!R97%U:7)E($9I
M;&4Z.E1E;7`["B`@("!R97%U:7)E($9I;&4Z.E-P96,["B`@("!R97%U:7)E
M(%A33&]A9&5R.PH@("`@<F5Q=6ER92!#;VYF:6<["B`@("!R97%U:7)E($E/
M.CI(86YD;&4["B`@("!R97%U:7)E($E/.CI&:6QE.PH@("`@<F5Q=6ER92!#
M;VUP<F5S<SHZ6FQI8CL*("`@(')E<75I<F4@07)C:&EV93HZ6FEP.PH@("`@
M<F5Q=6ER92!005(["B`@("!R97%U:7)E(%!!4CHZ2&5A=GD["B`@("!R97%U
M:7)E(%!!4CHZ1&ES=#L*("`@(')E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T
M<FEP.PH@("`@<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PH@
M("`@<F5Q=6ER92!A='1R:6)U=&5S.PH@("`@979A;"![(')E<75I<F4@0W=D
M('T["B`@("!E=F%L('L@<F5Q=6ER92!7:6XS,B!].PH@("`@979A;"![(')E
M<75I<F4@4V-A;&%R.CI5=&EL('T["B`@("!E=F%L('L@<F5Q=6ER92!!<F-H
M:79E.CI5;GII<#HZ0G5R<W0@?3L*("`@(&5V86P@>R!R97%U:7)E(%1I93HZ
M2&%S:#HZ3F%M961#87!T=7)E('T["B`@("!E=F%L('L@<F5Q=6ER92!097)L
M24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*?0H*(R!4:&4@0R!V97)S
M:6]N(&]F('1H:7,@8V]D92!A<'!E87)S(&EN(&UY;&1R+VUK=&UP9&ER+F,*
M(R!4:&ES(&-O9&4@86QS;R!L:79E<R!I;B!005(Z.E-E='5P5&5M<"!A<R!S
M971?<&%R7W1E;7!?96YV(0IS=6(@7W-E=%]P87)?=&5M<"!["B`@("!I9B`H
M9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@
M+R@N*RDO*2!["B`@("`@("`@)'!A<E]T96UP(#T@)#$["B`@("`@("`@<F5T
M=7)N.PH@("`@?0H*("`@(&9O<F5A8V@@;7D@)'!A=&@@*`H@("`@("`@("AM
M87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%
M35`@5$U0("DI+`H@("`@("`@('%W*"!#.EQ<5$5-4"`O=&UP("X@*0H@("`@
M*2!["B`@("`@("`@;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@
M)'!A=&@@86YD("UW("1P871H.PH@("`@("`@(&UY("1U<V5R;F%M93L*("`@
M("`@("!M>2`D<'=U:60["B`@("`@("`@(R!D;V5S(&YO="!W;W)K(&5V97)Y
M=VAE<F4Z"B`@("`@("`@979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@
M:68@9&5F:6YE9"`D/CM].PH*("`@("`@("!I9B`H(&1E9FEN960H)E=I;C,R
M.CI,;V=I;DYA;64I("D@>PH@("`@("`@("`@("`D=7-E<FYA;64@/2`F5VEN
M,S(Z.DQO9VEN3F%M93L*("`@("`@("!]"B`@("`@("`@96QS:68@*&1E9FEN
M960@)'!W=6ED*2!["B`@("`@("`@("`@("1U<V5R;F%M92`]("1P=W5I9#L*
M("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@("1U<V5R;F%M
M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<[
M"B`@("`@("`@?0H@("`@("`@("1U<V5R;F%M92`]?B!S+UQ7+U\O9SL*"B`@
M("`@("`@;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP87(M
M)'5S97)N86UE(CL*("`@("`@("!M:V1I<B`D<W1M<&1I<BP@,#<U-3L*("`@
M("`@("!I9B`H(21%3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@*'-T
M870H)'!R;V=N86UE*2E;.5TI('L*("`@("`@("`@("`@;W!E;B`H;7D@)&9H
M+"`B/"(N("1P<F]G;F%M92D["B`@("`@("`@("`@('-E96L@)&9H+"`M,3@L
M(#(["B`@("`@("`@("`@('-Y<W)E860@)&9H+"!M>2`D8G5F+"`V.PH@("`@
M("`@("`@("!I9B`H)&)U9B!E<2`B7#!#04-(12(I('L*("`@("`@("`@("`@
M("`@('-E96L@)&9H+"`M-3@L(#(["B`@("`@("`@("`@("`@("!S>7-R96%D
M("1F:"P@)&)U9BP@-#$["B`@("`@("`@("`@("`@("`D8G5F(#U^(',O7#`O
M+V<["B`@("`@("`@("`@("`@("`D<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L
M:6U]8V%C:&4M(B`N("1B=68["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M96QS92!["B`@("`@("`@("`@("`@("!M>2`D8W1X(#T@979A;"![(')E<75I
M<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0H@("`@("`@
M("`@("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@
M1&EG97-T.CI32$$Q+3YN97<@?0H@("`@("`@("`@("`@("`@("`@('Q\(&5V
M86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T[
M"@H@("`@("`@("`@("`@("`@(R!7;W)K87)O=6YD(&9O<B!B=6<@:6X@1&EG
M97-T.CI32$$@-2XS."!A;F0@-2XS.0H@("`@("`@("`@("`@("`@;7D@)'-H
M85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\
M(#`["B`@("`@("`@("`@("`@("!I9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X
M)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B`@("`@("`@("`@("`@
M("`@("`@)&-T>"T^861D9FEL92@D<')O9VYA;64L(")B(BD@:68@*"1C='@I
M.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@96QS92!["B`@
M("`@("`@("`@("`@("`@("`@:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B
M/"1P<F]G;F%M92(I*2!["B`@("`@("`@("`@("`@("`@("`@("`@(&)I;FUO
M9&4H)&9H*3L*("`@("`@("`@("`@("`@("`@("`@("`@)&-T>"T^861D9FEL
M92@D9F@I.PH@("`@("`@("`@("`@("`@("`@("`@("!C;&]S92@D9F@I.PH@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*"B`@("`@
M("`@("`@("`@("`D<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M
M(B`N("@@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM92`I.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(&-L;W-E*"1F:"D["B`@("`@("`@?0H@
M("`@("`@(&5L<V4@>PH@("`@("`@("`@("`D14Y6>U!!4E]#3$5!3GT@/2`Q
M.PH@("`@("`@("`@("`D<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]=&5M
M<"TD)"(["B`@("`@("`@?0H*("`@("`@("`D14Y6>U!!4E]414U0?2`]("1S
M=&UP9&ER.PH@("`@("`@(&UK9&ER("1S=&UP9&ER+"`P-S4U.PH@("`@("`@
M(&QA<W0["B`@("!]"@H@("`@)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?
M5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0H*<W5B(%]T
M96UP9FEL92!["B`@("!M>2`H)&5X="P@)&-R8RD@/2!`7SL*("`@(&UY("@D
M9F@L("1F:6QE;F%M92D["@H@("`@)&9I;&5N86UE(#T@(B1P87)?=&5M<"\D
M8W)C)&5X="(["@H@("`@:68@*"1%3E9[4$%27T-,14%.?2D@>PH@("`@("`@
M('5N;&EN:R`D9FEL96YA;64@:68@+64@)&9I;&5N86UE.PH@("`@("`@('!U
M<V@@0'1M<&9I;&4L("1F:6QE;F%M93L*("`@('T*("`@(&5L<V4@>PH@("`@
M("`@(')E='5R;B`H=6YD968L("1F:6QE;F%M92D@:68@*"UR("1F:6QE;F%M
M92D["B`@("!]"@H@("`@;W!E;B`D9F@L("<^)RP@)&9I;&5N86UE(&]R(&1I
M92`D(3L*("`@(&)I;FUO9&4H)&9H*3L*("`@(')E='5R;B@D9F@L("1F:6QE
M;F%M92D["GT*"B,@<V%M92!C;V1E(&QI=F5S(&EN(%!!4CHZ4V5T=7!0<F]G
M;F%M93HZ<V5T7W!R;V=N86UE"G-U8B!?<V5T7W!R;V=N86UE('L*("`@(&EF
M("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/
M1TY!345](#U^("\H+BLI+RD@>PH@("`@("`@("1P<F]G;F%M92`]("0Q.PH@
M("`@?0H*("`@("1P<F]G;F%M92!\?#T@)#`["@H@("`@:68@*"1%3E9[4$%2
M7U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^
M/2`P*2!["B`@("`@("`@)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@
M<FEN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PH@("`@
M?0H*("`@(&EF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G
M;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2!["B`@("`@("`@:68@*&]P
M96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PH@("`@("`@("`@("!R971U
M<FX@:68@+7,@)&9H.PH@("`@("`@('T*("`@("`@("!I9B`H+7,@(B1P<F]G
M;F%M921#;VYF:6=[7V5X97TB*2!["B`@("`@("`@("`@("1P<F]G;F%M92`N
M/2`D0V]N9FEG>U]E>&5].PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@
M?0H@("`@?0H*("`@(&9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O;F9I
M9WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*("`@("`@("!N97AT(&EF
M(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]4
M14U0?3L*("`@("`@("`D9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<120O
M+SL*("`@("`@("`H*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U]
M)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L87-T*0H@("`@("`@("`@("!I
M9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X
M97TB.PH@("`@("`@("@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI
M;7TD<')O9VYA;64B*2P@;&%S="D*("`@("`@("`@("`@:68@+7,@(B1D:7(D
M0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PH@("`@?0I]"@IS=6(@7V9I>%]P
M<F]G;F%M92!["B`@("`D,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/
M1TY!345].PH@("`@:68@*&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L
M:6U]*2`\(#`I('L*("`@("`@("`D<')O9VYA;64@/2`B+B1#;VYF:6=[7V1E
M;&EM?21P<F]G;F%M92(["B`@("!]"@H@("`@(R!86%@@+2!H86-K('1O(&UA
M:V4@4%=$('=O<FL*("`@(&UY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C
M=V0I(#\@0W=D.CIG971C=V0H*0H@("`@("`@("`@("`@("`@.B`H*&1E9FEN
M960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I
M.PH@("`@8VAO;7`H)'!W9"D["B`@("`D<')O9VYA;64@/7X@<R]>*#\]7"Y<
M+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]+SL*
M"B`@("`D14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*"G-U8B!?
M<&%R7VEN:71?96YV('L*("`@(&EF("@@)$5.5GM005)?24Y)5$E!3$E:141]
M*RL@/3T@,2`I('L*("`@("`@("!R971U<FX["B`@("!](&5L<V4@>PH@("`@
M("`@("1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["B`@("!]"@H@("`@9F]R
M("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%
M($%21T,@05)'5E\P("D@*2!["B`@("`@("`@9&5L971E("1%3E9[)U!!4E\G
M+B1??3L*("`@('T*("`@(&9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%
M0E5'("\I('L*("`@("`@("`D14Y6>R=005)?)RXD7WT@/2`D14Y6>R=005)?
M1TQ/0D%,7R<N)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]]
M.PH@("`@?0H*("`@(&UY("1P87)?8VQE86X@/2`B7U]%3E9?4$%27T-,14%.
M7U\@("`@("`@("`@("`@("`B.PH*("`@(&EF("@D14Y6>U!!4E]414U0?2D@
M>PH@("`@("`@(&1E;&5T92`D14Y6>U!!4E]#3$5!3GT["B`@("!]"B`@("!E
M;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2!["B`@("`@
M("`@;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N9W1H
M*")#3$5!3B(I*3L*("`@("`@("`D14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D
M=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO.PH@("`@?0I]"@IS=6(@;W5T
M<R!["B`@("!R971U<FX@:68@)'%U:65T.PH@("`@:68@*"1L;V=F:"D@>PH@
M("`@("`@('!R:6YT("1L;V=F:"`B0%]<;B(["B`@("!]"B`@("!E;'-E('L*
M("`@("`@("!P<FEN="`B0%]<;B(["B`@("!]"GT*"G-U8B!I;FET7VEN8R![
M"B`@("!R97%U:7)E($-O;F9I9SL*("`@('!U<V@@0$E.0RP@9W)E<"!D969I
M;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"B`@("`@("`@87)C
M:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*("`@
M("`@("!V96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`H@("`@*3L*?0H*(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C"B,@5&AE(&UA:6X@<&%C:V%G92!F
M;W(@<V-R:7!T(&5X96-U=&EO;@H*<&%C:V%G92!M86EN.PH*<F5Q=6ER92!0
M05(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R
M="A`<&%R7V%R9W,I.PH*9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P97)L
M('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R
M>5QN*0H@("`@=6YL97-S("UE("1P<F]G;F%M93L*"F1O("1P<F]G;F%M93L*
M0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO
M*3L*9&EE("1`(&EF("1`.PH*?3L*"B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*
M?0H*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E4
M7UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PH*
M,3L*"B-L:6YE(#$P,3$*"E]?14Y$7U\*````````````````````````````
M`````$`7``!`%P``0!<``$`7``!`%P``0!<``$`7``!`%P``0!<``$`7``!`
M%P``0!<``$`7``!`%P``0!<``$`7``!`%P``0!<``$`7``!`%P``0!<``$`7
M``!`%P``0!<``$`7``!`%P``0!<``$`7``!`%P``0!<``$`7``!`%P``0!<`
M`$`7``!`%P``0!<``$`7``!`%P``0!<``$`7``!`%P``0!<``$`7``!`%P``
M0!<``$`7``!`%P``0!<``$`7``!`%P``0!<``$`7``!`%P``0!<``$`7``!`
M%P``0!<``$`7``!`%P``0!<``$`7``!`%P``0!<``$`7``!`%P``````@```
M``!`&S``0%9(`$!60`!!O2``0!:(`$%@````````0%=P``````!`5V``````
M1T-#.B`H1&5B:6%N(#0N-BXR+30I(#0N-BXR`$=#0SH@*$1E8FEA;B`T+C0N
M-BTQ,2D@-"XT+C8``````$`>P``#``#____\``````````````*(````'0``
M`!\`0#&`@'\``/____P``````````````#@````=````'P!`,J"`````____
M_```````````````*````!T````?`$`RO(`#``#____\```````````````P
M````'0```!\`0#-`@`<``/____P``````````````"@````=````'P!`-'R`
M?P``_____```````````````V````!T````?`$`V%(`#``#____\````````
M```````H````'0```!\`0#;`@/\``/____P``````````````$@````=````
M'P!`.2"`#P``_____``````````````0.````!T````?`$`Z$(````#____\
M```````````````@````'0```!\`0#I0@`$``/____P``````````````"@`
M```=````'P!`.KB`!P``_____``````````````@.````!T````?`$`[>```
M````````````````````````````'0```!\`0#N`P/\``/____P`````````
M````$%@````=````'P!`/8```````````````````````````````!T````?
M`$`]Q(`#``#____\```````````````H````'0```!\`0#\T@!\``/____P`
M`````````````%@````=````'P!`02R``0``_____```````````````(```
M`!T````?`$!!H(````#____\```````````````@````'0```!\`0$'8@'\`
M`/____P``````````````&`````=````'P!`0SC`_P``_____```````````
M``"!6````!T````?`$!0L,#_``#____\``````````````!(````'0```!\`
M0%3L@`,``/____P``````````````"@````=````'P!`5:"``0``_____```
M````````````(````!T````?`$`;,(`'``#____\```````````````P````
M'0```!\`0%8````````````````````````````````=````'P!`5D``````
M`````````````````````````!T````?`$!62(`_``#____\````````````
M```X````'0```!]!````#V=N=0`!````!P0!`"YS:'-T<G1A8@`N:6YT97)P
M`"YN;W1E+D%"22UT86<`+G)E9VEN9F\`+FYO=&4N9VYU+F)U:6QD+6ED`"YD
M>6YA;6EC`"YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N
M=2YV97)S:6]N7W(`+G)E;"YD>6X`+G)E;"YP;'0`+FEN:70`+G1E>'0`+DU)
M4%,N<W1U8G,`+F9I;FD`+G)O9&%T80`N96A?9G)A;64`+F-T;W)S`"YD=&]R
M<P`N:F-R`"YD871A`"YR;&1?;6%P`"YG;W0N<&QT`"YG;W0`+G-D871A`"YB
M<W,`+F-O;6UE;G0`+G!D<@`N9VYU+F%T=')I8G5T97,`+FUD96)U9RYA8FDS
M,@``````````````````````````````````````````````````````````
M```+`````0````(`0`%4```!5`````T```````````````$`````````$P``
M``<````"`$`!9````60````@```````````````$`````````"%P```&````
M`@!``80```&$````&```````````````!````!@````J````!P````(`0`&<
M```!G````"0```````````````0`````````/0````8````"`$`!P````<``
M``%`````"``````````$````"````$8````%`````@!``P````,````#3```
M``<`````````!`````0```!,````"P````(`0`9,```&3```!P`````(````
M`0````0````0````5`````,````"`$`-3```#4P```5L```````````````!
M`````````%QO____`````@!`$K@``!*X````X`````<``````````@````(`
M``!I;____@````(`0!.8```3F````+`````(`````P````0`````````>```
M``D````"`$`42```%$@````X````!P`````````$````"````($````)````
M`@!`%(```!2````""`````<````.````!`````@```"*`````0````8`0!:(
M```6B````&@```````````````0`````````A0````$````&`$`7````%P``
M``0P```````````````@`````````)`````!````!@!`&S```!LP```\,```
M````````````$`````````"6`````0````8`0%=@``!78````#``````````
M``````0`````````H@````$````&`$!7D```5Y`````X```````````````$
M`````````*@````!`````@!`5]```%?0```#X```````````````$```````
M``"P`````0````(`0%NP``!;L`````0```````````````0`````````N@``
M``$````#`$%@````8``````(```````````````$`````````,$````!````
M`P!!8`@``&`(````"```````````````!`````````#(`````0````,`06`0
M``!@$`````0```````````````0`````````S0````$````#`$%@(```8"``
M`%O````````````````0`````````-,````!`````P!!N^```+O@````!```
M````````````!`````````#<`````0````,`0;OD``"[Y````0P`````````
M``````0`````````Y0````$0```#`$&\\```O/`````P```````````````0
M````!````.H````!$````P!!O2```+T@````!```````````````!```````
M``#Q````"`````,`0;TP``"])```$&```````````````!``````````]@``
M``$````P````````O20````Y```````````````!`````0```/\````!````
M`````````+U@```#@```````````````!`````````$$;___]0``````````
M``#`X````!````````````````$````````!%`````$``````$'-D```P/``
M```````````````````!``````````$````#`````````````,#P```!(@``
.`````````````0``````
